@@ -75,14 +75,12 @@ sub scan {
     my $Re1        = {};    # (Ref->Hash) Delimiter patterns
     my $ReFailure  = {};    # (Ref->Hash) Error message patterns
     my $boundary00 = '';    # (String) Boundary string
-
     my $v = undef;
-    my $p = '';
 
     if( $vtext == 1 ) {
         # vtext.com
         $Re1 = {
-            'begin'  => qr/\AError:\s/,
+            'begin'  => qr/\AError:[ \t]/,
             'rfc822' => qr/\A__BOUNDARY_STRING_HERE__\z/,
             'endof'  => qr/\A__END_OF_EMAIL_MESSAGE__\z/,
         };
@@ -118,18 +116,16 @@ sub scan {
 
             if( $readcursor & $Indicators->{'message-rfc822'} ) {
                 # After "message/rfc822"
-                if( $e =~ m/\A\s\s([-0-9A-Za-z]+?)[:][ ]*.+\z/ ) {
+                if( $e =~ m/\A[ ][ ]([-0-9A-Za-z]+?)[:][ ]*.+\z/ ) {
                     # Get required headers only
-                    my $lhs = $1;
-                    my $whs = lc $lhs;
-
+                    my $lhs = lc $1;
                     $previousfn = '';
-                    next unless exists $RFC822Head->{ $whs };
+                    next unless exists $RFC822Head->{ $lhs };
 
-                    $previousfn  = lc $lhs;
+                    $previousfn  = $lhs;
                     $rfc822part .= $e."\n";
 
-                } elsif( $e =~ m/\A[\s\t]+/ ) {
+                } elsif( $e =~ m/\A[ \t]+/ ) {
                     # Continued line from the previous line
                     next if $rfc822next->{ $previousfn };
                     $rfc822part .= $e."\n" if exists $LongFields->{ $previousfn };
@@ -140,7 +136,6 @@ sub scan {
                     next if length $e;
                     $rfc822next->{ $previousfn } = 1;
                 }
-
             } else {
                 # Before "message/rfc822"
                 next unless $readcursor & $Indicators->{'deliverystatus'};
@@ -148,7 +143,7 @@ sub scan {
 
                 $v = $dscontents->[ -1 ];
 
-                if( $e =~ m/\A\s+RCPT TO: (.*)\z/ ) {
+                if( $e =~ m/\A[ \t]+RCPT TO: (.*)\z/ ) {
                     # Message details:
                     #   Subject: Test message
                     #   Sent date: Wed Jun 12 02:21:53 GMT 2013
@@ -164,29 +159,23 @@ sub scan {
                     $recipients++;
                     next;
 
-                } elsif( $e =~ m/\A\s+MAIL FROM:\s(.+)\z/ ) {
+                } elsif( $e =~ m/\A[ \t]+MAIL FROM:[ \t](.+)\z/ ) {
                     #   MAIL FROM: *******@hg.example.com
                     $senderaddr ||= $1;
 
-                } elsif( $e =~ m/\A\s+Subject:\s(.+)\z/ ) {
+                } elsif( $e =~ m/\A[ \t]+Subject:[ \t](.+)\z/ ) {
                     #   Subject:
                     $subjecttxt ||= $1;
 
                 } else {
 
-                    if( $e =~ m/\A(\d{3})\s[-]\s(.*)\z/ ) {
+                    if( $e =~ m/\A(\d{3})[ \t][-][ \t](.*)\z/ ) {
                         # 550 - Requested action not taken: no such user here
                         $v->{'diagnosis'} = $e;
                     }
                 }
             } # End of if: rfc822
-
-        } continue {
-            # Save the current line for the next loop
-            $p = $e;
-            $e = '';
         }
-
     } else {
         # vzwpix.com
         $Re1 = {
@@ -225,19 +214,16 @@ sub scan {
 
             if( $readcursor & $Indicators->{'message-rfc822'} ) {
                 # After "message/rfc822"
-                if( $e =~ m/\A\s\s([-0-9A-Za-z]+?)[:][ ]*(.+)\z/ ) {
+                if( $e =~ m/\A[ ][ ]([-0-9A-Za-z]+?)[:][ ]*(.+)\z/ ) {
                     # Get required headers only
-                    my $lhs = $1;
-                    my $rhs = $2;
-                    my $whs = lc $lhs;
-
+                    my $lhs = lc $1;
                     $previousfn = '';
-                    next unless exists $RFC822Head->{ $whs };
+                    next unless exists $RFC822Head->{ $lhs };
 
-                    $previousfn  = lc $lhs;
+                    $previousfn  = $lhs;
                     $rfc822part .= $e."\n";
 
-                } elsif( $e =~ m/\A[\s\t]+/ ) {
+                } elsif( $e =~ m/\A[ \t]+/ ) {
                     # Continued line from the previous line
                     next if $rfc822next->{ $previousfn };
                     $rfc822part .= $e."\n" if exists $LongFields->{ $previousfn };
@@ -248,7 +234,6 @@ sub scan {
                     next if length $e;
                     $rfc822next->{ $previousfn } = 1;
                 }
-
             } else {
                 # Before "message/rfc822"
                 next unless $readcursor & $Indicators->{'deliverystatus'};
@@ -256,7 +241,7 @@ sub scan {
 
                 $v = $dscontents->[ -1 ];
 
-                if( $e =~ m/\ATo:\s+(.*)\z/ ) {
+                if( $e =~ m/\ATo:[ \t]+(.*)\z/ ) {
                     # Original Message:
                     # From: kijitora <kijitora@example.jp>
                     # To: 0000000000@vzwpix.com
@@ -272,31 +257,25 @@ sub scan {
                     $recipients++;
                     next;
 
-                } elsif( $e =~ m/\AFrom:\s(.+)\z/ ) {
+                } elsif( $e =~ m/\AFrom:[ \t](.+)\z/ ) {
                     # From: kijitora <kijitora@example.jp>
                     $senderaddr ||= Sisimai::Address->s3s4( $1 );
 
-                } elsif( $e =~ m/\ASubject:\s(.+)\z/ ) {
+                } elsif( $e =~ m/\ASubject:[ \t](.+)\z/ ) {
                     #   Subject:
                     $subjecttxt ||= $1;
 
                 } else {
 
-                    if( $e =~ m/\AError:\s+(.+)\z/ ) {
+                    if( $e =~ m/\AError:[ \t]+(.+)\z/ ) {
                         # Message could not be delivered to mobile.
                         # Error: No valid recipients for this MM
                         $v->{'diagnosis'} = $e;
                     }
                 }
             } # End of if: rfc822
-
-        } continue {
-            # Save the current line for the next loop
-            $p = $e;
-            $e = undef;
         }
     }
-
     return undef unless $recipients;
 
     # Set the value of "MAIL FROM:" or "From:", and "Subject"
@@ -304,12 +283,9 @@ sub scan {
     $rfc822part .= sprintf( "Subject: %s\n", $subjecttxt ) unless $rfc822part =~ m/\bSubject: /;
 
     require Sisimai::String;
-    require Sisimai::RFC3463;
+    require Sisimai::SMTP::Status;
 
     for my $e ( @$dscontents ) {
-        # Set default values if each value is empty.
-        $e->{'agent'} = __PACKAGE__->smtpagent;
-
         if( scalar @{ $mhead->{'received'} } ) {
             # Get localhost and remote host name from Received header.
             my $r = $mhead->{'received'};
@@ -325,11 +301,11 @@ sub scan {
             last;
         }
 
-        $e->{'status'} = Sisimai::RFC3463->getdsn( $e->{'diagnosis'} );
+        $e->{'status'} = Sisimai::SMTP::Status->find( $e->{'diagnosis'} );
         $e->{'spec'}   = $e->{'reason'} eq 'mailererror' ? 'X-UNIX' : 'SMTP';
         $e->{'action'} = 'failed' if $e->{'status'} =~ m/\A[45]/;
-
-    } # end of for()
+        $e->{'agent'}  = __PACKAGE__->smtpagent;
+    }
 
     return { 'ds' => $dscontents, 'rfc822' => $rfc822part };
 }
@@ -377,8 +353,7 @@ azumakuniyuki
 
 =head1 COPYRIGHT
 
-Copyright (C) 2014-2015 azumakuniyuki E<lt>perl.org@azumakuniyuki.orgE<gt>,
-All Rights Reserved.
+Copyright (C) 2014-2015 azumakuniyuki, All rights reserved.
 
 =head1 LICENSE
 
