@@ -95,16 +95,15 @@ sub scan {
             # After "message/rfc822"
             if( $e =~ m/\A([-0-9A-Za-z]+?)[:][ ]*.+\z/ ) {
                 # Get required headers only
-                my $lhs = $1;
-                my $whs = lc $lhs;
+                my $lhs = lc $1;
 
                 $previousfn = '';
-                next unless exists $RFC822Head->{ $whs };
+                next unless exists $RFC822Head->{ $lhs };
 
-                $previousfn  = lc $lhs;
+                $previousfn  = $lhs;
                 $rfc822part .= $e."\n";
 
-            } elsif( $e =~ m/\A[\s\t]+/ ) {
+            } elsif( $e =~ m/\A[ \t]+/ ) {
                 # Continued line from the previous line
                 next if $rfc822next->{ $previousfn };
                 $rfc822part .= $e."\n" if exists $LongFields->{ $previousfn };
@@ -143,7 +142,7 @@ sub scan {
                 $v->{'recipient'} ||= $e;
                 $recipients++;
 
-            } elsif( $e =~ m/\A\s\s([^ ]+[@][^ ]+)\z/ ) {
+            } elsif( $e =~ m/\A[ ][ ]([^ ]+[@][^ ]+)\z/ ) {
                 # Continued from the line "was not delivered to:"
                 #   kijitora@example.net
                 $v->{'recipient'} = Sisimai::Address->s3s4( $1 );
@@ -158,25 +157,19 @@ sub scan {
                     # Error message, continued from the line "because:"
                     $v->{'diagnosis'} = $e;
 
-                } elsif( $e =~ m/\A\s\sSubject: (.+)\z/ ) {
+                } elsif( $e =~ m/\A[ ][ ]Subject: (.+)\z/ ) {
                     #   Subject: Nyaa
                     $subjecttxt = $1;
                 }
             }
         } # End of if: rfc822
-
-    } continue {
-        # Save the current line for the next loop
-        $p = $e;
-        $e = '';
     }
     return undef unless $recipients;
 
     require Sisimai::String;
-    require Sisimai::RFC3463;
+    require Sisimai::SMTP::Status;
 
     for my $e ( @$dscontents ) {
-        # Set default values if each value is empty.
         $e->{'agent'} = __PACKAGE__->smtpagent;
 
         if( scalar @{ $mhead->{'received'} } ) {
@@ -192,8 +185,8 @@ sub scan {
             # Check each regular expression of Domino error messages
             next unless $e->{'diagnosis'} =~ $ReFailure->{ $r };
             $e->{'reason'} = $r;
-            my $s = Sisimai::RFC3463->status( $r, 'p', 'i' );
-            $e->{'status'} = $s if length $s;
+            my $pseudostatus = Sisimai::SMTP::Status->code( $r, 0 );
+            $e->{'status'} = $pseudostatus if length $pseudostatus;
             last;
         }
 
@@ -204,8 +197,7 @@ sub scan {
             # Fallback: Add the value of Subject as a Subject header
             $rfc822part .= sprintf( "Subject: %s\n", $subjecttxt );
         }
-
-    } # end of for()
+    }
 
     return { 'ds' => $dscontents, 'rfc822' => $rfc822part };
 }
@@ -253,8 +245,7 @@ azumakuniyuki
 
 =head1 COPYRIGHT
 
-Copyright (C) 2014-2015 azumakuniyuki E<lt>perl.org@azumakuniyuki.orgE<gt>,
-All Rights Reserved.
+Copyright (C) 2014-2015 azumakuniyuki, All rights reserved.
 
 =head1 LICENSE
 
