@@ -123,7 +123,6 @@ sub scan {
     };
 
     my $v = undef;
-    my $p = '';
 
     for my $e ( @hasdivided ) {
         # Read each line between $Re1->{'begin'} and $Re1->{'rfc822'}.
@@ -147,16 +146,14 @@ sub scan {
             # After "message/rfc822"
             if( $e =~ m/\A([-0-9A-Za-z]+?)[:][ ]*.+\z/ ) {
                 # Get required headers only
-                my $lhs = $1;
-                my $whs = lc $lhs;
-
+                my $lhs = lc $1;
                 $previousfn = '';
-                next unless exists $RFC822Head->{ $whs };
+                next unless exists $RFC822Head->{ $lhs };
 
-                $previousfn  = lc $lhs;
+                $previousfn  = $lhs;
                 $rfc822part .= $e."\n";
 
-            } elsif( $e =~ m/\A[\s\t]+/ ) {
+            } elsif( $e =~ m/\A[ \t]+/ ) {
                 # Continued line from the previous line
                 $rfc822part .= $e."\n" if exists $LongFields->{ $previousfn };
                 next if $rfc822next->{ $previousfn };
@@ -188,8 +185,8 @@ sub scan {
                 #     MSEXCH:IMS:KIJITORA CAT:EXAMPLE:EXCHANGE 0 (000C05A6) Unknown Recipient
                 $v = $dscontents->[ -1 ];
 
-                if( $e =~ m/\A\s*([^ ]+[@][^ ]+) on\s*.*\z/ ||
-                    $e =~ m/\A\s*.+(?:SMTP|smtp)=([^ ]+[@][^ ]+) on\s*.*\z/ ) {
+                if( $e =~ m/\A[ \t]*([^ ]+[@][^ ]+) on[ \t]*.*\z/ ||
+                    $e =~ m/\A[ \t]*.+(?:SMTP|smtp)=([^ ]+[@][^ ]+) on[ \t]*.*\z/ ) {
                     # kijitora@example.co.jp on Thu, 29 Apr 2007 16:51:51 -0500
                     #   kijitora@example.com on 4/29/99 9:19:59 AM
                     if( length $v->{'recipient'} ) {
@@ -201,7 +198,7 @@ sub scan {
                     $v->{'msexch'} = 0;
                     $recipients++;
 
-                } elsif( $e =~ m/\A\s+(MSEXCH:.+)\z/ ) {
+                } elsif( $e =~ m/\A[ \t]+(MSEXCH:.+)\z/ ) {
                     #     MSEXCH:IMS:KIJITORA CAT:EXAMPLE:EXCHANGE 0 (000C05A6) Unknown Recipient
                     $v->{'diagnosis'} .= $1;
 
@@ -227,20 +224,20 @@ sub scan {
                 #  Subject: ...
                 #  Sent:    Thu, 29 Apr 2010 18:14:35 +0000
                 #
-                if( $e =~ m/\A\s+To:\s+(.+)\z/ ) {
+                if( $e =~ m/\A[ \t]+To:[ \t]+(.+)\z/ ) {
                     #  To:      shironeko@example.jp
                     next if length $connheader->{'to'};
                     $connheader->{'to'} = $1;
                     $connvalues++;
 
-                } elsif( $e =~ m/\A\s+Subject:\s+(.+)\z/ ) {
+                } elsif( $e =~ m/\A[ \t]+Subject:[ \t]+(.+)\z/ ) {
                     #  Subject: ...
                     next if length $connheader->{'subject'};
                     $connheader->{'subject'} = $1;
                     $connvalues++;
 
-                } elsif( $e =~ m/\A\s+Sent:\s+([A-Z][a-z]{2},.+[-+]\d{4})\z/ ||
-                         $e =~ m|\A\s+Sent:\s+(\d+[/]\d+[/]\d+\s+\d+:\d+:\d+\s.+)|) {
+                } elsif( $e =~ m/\A[ \t]+Sent:[ \t]+([A-Z][a-z]{2},.+[-+]\d{4})\z/ ||
+                         $e =~ m|\A[ \t]+Sent:[ \t]+(\d+[/]\d+[/]\d+[ \t]+\d+:\d+:\d+[ \t].+)|) {
                     #  Sent:    Thu, 29 Apr 2010 18:14:35 +0000
                     #  Sent:    4/29/99 9:19:59 AM
                     next if length $connheader->{'date'};
@@ -249,41 +246,37 @@ sub scan {
                 }
             }
         } # End of if: rfc822
-
-    } continue {
-        # Save the current line for the next loop
-        $p = $e;
-        $e = '';
     }
 
     return undef unless $recipients;
     require Sisimai::String;
-    require Sisimai::RFC3463;
+    require Sisimai::SMTP::Status;
 
     for my $e ( @$dscontents ) {
 
         if( scalar @{ $mhead->{'received'} } ) {
             # Get localhost and remote host name from Received header.
-            my $r = $mhead->{'received'};
-            $e->{'lhost'} ||= shift @{ Sisimai::RFC5322->received( $r->[0] ) };
-            $e->{'rhost'} ||= pop @{ Sisimai::RFC5322->received( $r->[-1] ) };
+            my $r0 = $mhead->{'received'};
+            $e->{'lhost'} ||= shift @{ Sisimai::RFC5322->received( $r0->[0] ) };
+            $e->{'rhost'} ||= pop @{ Sisimai::RFC5322->received( $r0->[-1] ) };
         }
         $e->{'diagnosis'} = Sisimai::String->sweep( $e->{'diagnosis'} );
 
-        if( $e->{'diagnosis'} =~ m{\AMSEXCH:.+\s*[(]([0-9A-F]{8})[)]\s*(.*)\z} ) {
+        if( $e->{'diagnosis'} =~ m{\AMSEXCH:.+[ \t]*[(]([0-9A-F]{8})[)][ \t]*(.*)\z} ) {
             #     MSEXCH:IMS:KIJITORA CAT:EXAMPLE:EXCHANGE 0 (000C05A6) Unknown Recipient
-            my $c = $1;
-            my $d = $2;
-            my $s = '';
+            my $capturedcode = $1;
+            my $errormessage = $2;
+            my $pseudostatus = '';
 
             for my $r ( keys %$ErrorCodeTable ) {
-                next unless grep { $c eq $_ } @{ $ErrorCodeTable->{ $r } };
+                # Find captured code from the error code table
+                next unless grep { $capturedcode eq $_ } @{ $ErrorCodeTable->{ $r } };
                 $e->{'reason'} = $r;
-                $s = Sisimai::RFC3463->status( $r, 'p', 'i' );
-                $e->{'status'} = $s if length $s;
+                $pseudostatus = Sisimai::SMTP::Status->code( $r );
+                $e->{'status'} = $pseudostatus if length $pseudostatus;
                 last;
             }
-            $e->{'diagnosis'} = $d;
+            $e->{'diagnosis'} = $errormessage;
         }
 
         unless( $e->{'reason'} ) {
@@ -299,10 +292,8 @@ sub scan {
         $e->{'spec'}   = $e->{'reason'} eq 'mailererror' ? 'X-UNIX' : 'SMTP';
         $e->{'action'} = 'failed' if $e->{'status'} =~ m/\A[45]/;
         $e->{'agent'}  = __PACKAGE__->smtpagent;
-
         delete $e->{'msexch'};
-
-    } # end of for()
+    }
 
     if( length( $rfc822part ) == 0 ) {
         # When original message does not included in the bounce message
@@ -357,8 +348,7 @@ azumakuniyuki
 
 =head1 COPYRIGHT
 
-Copyright (C) 2014-2015 azumakuniyuki E<lt>perl.org@azumakuniyuki.orgE<gt>,
-All Rights Reserved.
+Copyright (C) 2014-2015 azumakuniyuki, All rights reserved.
 
 =head1 LICENSE
 
