@@ -15,7 +15,7 @@ my $Re0 = {
         |error[(]s[)][ ]in[ ]forwarding[ ]or[ ]filtering
         )
     }x,
-    'message-id'=> qr/\A[<]\w+[-]\w+[-]\w+[@].+\z/,
+    #'message-id'=> qr/\A[<]\w+[-]\w+[-]\w+[@].+\z/,
     # Message-Id: <E1P1YNN-0003AD-Ga@example.org>
 };
 
@@ -68,68 +68,60 @@ my $ReCommand = [
     qr/LMTP error after end of ([A-Za-z]{4})/,
 ];
 
+# find exim/ -type f -exec grep 'message = US' {} /dev/null \;
 my $ReFailure = {
-    # find exim/ -type f -exec grep 'message = US' {} /dev/null \;
-    'userunknown' => qr{
-        # route.c:1158|  DEBUG(D_uid) debug_printf("getpwnam() returned NULL (user not found)\n");
-        user[ ]not[ ]found
-    }x,
+    # route.c:1158|  DEBUG(D_uid) debug_printf("getpwnam() returned NULL (user not found)\n");
+    'userunknown' => qr/user[ ]not[ ]found/x,
+    # transports/smtp.c:3524|  addr->message = US"all host address lookups failed permanently";
+    # routers/dnslookup.c:331|  addr->message = US"all relevant MX records point to non-existent hosts";
+    # route.c:1826|  uschar *message = US"Unrouteable address";
     'hostunknown' => qr{(?>
          all[ ](?:
-            # transports/smtp.c:3524|  addr->message = US"all host address lookups failed permanently";
              host[ ]address[ ]lookups[ ]failed[ ]permanently
-            # routers/dnslookup.c:331|  addr->message = US"all relevant MX records point to non-existent hosts";
             |relevant[ ]MX[ ]records[ ]point[ ]to[ ]non[-]existent[ ]hosts
             )
-        # route.c:1826|  uschar *message = US"Unrouteable address";
         |Unrouteable[ ]address
         )
     }x,
-    'mailboxfull' => qr{(?:
-        # transports/appendfile.c:2567|  addr->user_message = US"mailbox is full";
-         mailbox[ ]is[ ]full:?
-        # transports/appendfile.c:3049|  addr->message = string_sprintf("mailbox is full "$                          
-        # transports/appendfile.c:3050|  "(quota exceeded while writing to file %s)", filename);$
-        |error:[ ]quota[ ]exceed
-        )
-    }x,
+    # transports/appendfile.c:2567|  addr->user_message = US"mailbox is full";
+    # transports/appendfile.c:3049|  addr->message = string_sprintf("mailbox is full "
+    # transports/appendfile.c:3050|  "(quota exceeded while writing to file %s)", filename);
+    'mailboxfull' => qr/(?:mailbox[ ]is[ ]full:?|error:[ ]quota[ ]exceed)/x,
+    # routers/dnslookup.c:328|  addr->message = US"an MX or SRV record indicated no SMTP service";
+    # transports/smtp.c:3502|  addr->message = US"no host found for existing SMTP connection";
     'notaccept' => qr{(?:
-        # routers/dnslookup.c:328|  addr->message = US"an MX or SRV record indicated no SMTP service";
          an[ ]MX[ ]or[ ]SRV[ ]record[ ]indicated[ ]no[ ]SMTP[ ]service
-        # transports/smtp.c:3502|  addr->message = US"no host found for existing SMTP connection";
         |no[ ]host[ ]found[ ]for[ ]existing[ ]SMTP[ ]connection
         )
     }x,
+    # deliver.c:5614|  addr->message = US"delivery to file forbidden";
+    # deliver.c:5624|  addr->message = US"delivery to pipe forbidden";
+    # transports/pipe.c:1156|  addr->user_message = US"local delivery failed";
     'systemerror' => qr{(?>
-        # deliver.c:5614|  addr->message = US"delivery to file forbidden";
-        # deliver.c:5624|  addr->message = US"delivery to pipe forbidden";
          delivery[ ]to[ ](?:file|pipe)[ ]forbidden
-        # transports/pipe.c:1156|  addr->user_message = US"local delivery failed";
         |local[ ]delivery[ ]failed
         |LMTP[ ]error[ ]after[ ]
         )
     }x,
-    'contenterror' => qr{
-        # deliver.c:5425|  new->message = US"Too many \"Received\" headers - suspected mail loop";
-        Too[ ]many[ ]["]Received["][ ]headers
-    }x,
+    # deliver.c:5425|  new->message = US"Too many \"Received\" headers - suspected mail loop";
+    'contenterror' => qr/Too[ ]many[ ]["]Received["][ ]headers/x,
 };
 
+# retry.c:902|  addr->message = (addr->message == NULL)? US"retry timeout exceeded" :
+# deliver.c:7475|  "No action is required on your part. Delivery attempts will continue for\n"
+# smtp.c:3508|  US"retry time not reached for any host after a long failure period" :
+# smtp.c:3508|  US"all hosts have been failing for a long time and were last tried "
+#                 "after this message arrived";
+# deliver.c:7459|  print_address_error(addr, f, US"Delay reason: ");
+# deliver.c:7586|  "Message %s has been frozen%s.\nThe sender is <%s>.\n", message_id,
+# receive.c:4021|  moan_tell_someone(freeze_tell, NULL, US"Message frozen on arrival",
+# receive.c:4022|  "Message %s was frozen on arrival by %s.\nThe sender is <%s>.\n",
 my $ReDelayed = qr{(?:
-    # retry.c:902|  addr->message = (addr->message == NULL)? US"retry timeout exceeded" :
      retry[ ]timeout[ ]exceeded
-    # deliver.c:7475|  "No action is required on your part. Delivery attempts will continue for\n"
     |No[ ]action[ ]is[ ]required[ ]on[ ]your[ ]part
-    # smtp.c:3508|  US"retry time not reached for any host after a long failure period" :
-    # smtp.c:3508|  US"all hosts have been failing for a long time and were last tried "
-    #                 "after this message arrived";
     |retry[ ]time[ ]not[ ]reached[ ]for[ ]any[ ]host[ ]after[ ]a[ ]long[ ]failure[ ]period
     |all[ ]hosts[ ]have[ ]been[ ]failing[ ]for[ ]a[ ]long[ ]time[ ]and[ ]were[ ]last[ ]tried
-    # deliver.c:7459|  print_address_error(addr, f, US"Delay reason: ");
     |Delay[ ]reason:[ ]
-    # deliver.c:7586|  "Message %s has been frozen%s.\nThe sender is <%s>.\n", message_id,
-    # receive.c:4021|  moan_tell_someone(freeze_tell, NULL, US"Message frozen on arrival",
-    # receive.c:4022|  "Message %s was frozen on arrival by %s.\nThe sender is <%s>.\n",
     |Message[ ].+[ ](?:has[ ]been[ ]frozen|was[ ]frozen[ ]on[ ]arrival[ ]by[ ])
     )
 }x;
@@ -173,9 +165,7 @@ sub scan {
     my $localhost0 = '';    # (String) Local MTA
     my $boundary00 = '';    # (String) Boundary string
     my $rxboundary = undef; # (String) Regular expression for matching with the boundary
-
     my $v = undef;
-    my $p = '';
 
     if( $mhead->{'content-type'} ) {
         # Get the boundary string and set regular expression for matching with
@@ -209,17 +199,14 @@ sub scan {
             # After "message/rfc822"
             if( $e =~ m/\A([-0-9A-Za-z]+?)[:][ ]*.+\z/ ) {
                 # Get required headers only
-                my $lhs = $1;
-                my $rhs = $2;
-                my $whs = lc $lhs;
-
+                my $lhs = lc $1;
                 $previousfn = '';
-                next unless exists $RFC822Head->{ $whs };
+                next unless exists $RFC822Head->{ $lhs };
 
-                $previousfn  = lc $lhs;
+                $previousfn  = $lhs;
                 $rfc822part .= $e."\n";
 
-            } elsif( $e =~ m/\A[\s\t]+/ ) {
+            } elsif( $e =~ m/\A[ \t]+/ ) {
                 # Continued line from the previous line
                 next if $rfc822next->{ $previousfn };
                 $rfc822part .= $e."\n" if exists $LongFields->{ $previousfn };
@@ -246,11 +233,11 @@ sub scan {
             #    host neko.example.jp [192.0.2.222]: 550 5.1.1 <kijitora@example.jp>... User Unknown
             $v = $dscontents->[ -1 ];
 
-            if( $e =~ m/\s*This is a permanent error[.]\s*/ ) {
+            if( $e =~ m/[ \t]*This is a permanent error[.][ \t]*/ ) {
                 # deliver.c:6811|  "recipients. This is a permanent error. The following address(es) failed:\n");
                 $v->{'softbounce'} = 0;
 
-            } elsif( $e =~ m/\A\s+([^\s\t]+[@][^\s\t]+[.][a-zA-Z]+)(:.+)?\z/ || $e =~ $Re1->{'alias'} ) {
+            } elsif( $e =~ m/\A[ \t]+([^ \t]+[@][^ \t]+[.][a-zA-Z]+)(:.+)?\z/ || $e =~ $Re1->{'alias'} ) {
                 #   kijitora@example.jp
                 #   sabineko@example.jp: forced freeze
                 #
@@ -266,7 +253,7 @@ sub scan {
                 $recipients++;
 
             } elsif( $e =~ m/\A[ ]+[(]generated[ ]from[ ](.+)[)]\z/ ||
-                     $e =~ m/\A[ ]+generated[ ]by[ ]([^\s\t]+[@][^\s\t]+)/ ) {
+                     $e =~ m/\A[ ]+generated[ ]by[ ]([^ \t]+[@][^ \t]+)/ ) {
                 #     (generated from kijitora@example.jp)
                 #  pipe to |/bin/echo "Some pipe output"
                 #    generated by userx@myhost.test.ex
@@ -321,18 +308,13 @@ sub scan {
                         } else {
                             # Error message when email address above does not include '@'
                             # and domain part.
-                            next unless $e =~ m/\A\s{4}/;
+                            next unless $e =~ m/\A[ ]{4}/;
                             $v->{'alterrors'} .= $e.' ';
                         }
                     }
                 }
             }
         } # End of if: rfc822
-
-    } continue {
-        # Save the current line for the next loop
-        $p = $e;
-        $e = '';
     }
 
     if( $recipients ) {
@@ -351,7 +333,7 @@ sub scan {
         if( defined $mhead->{'x-failed-recipients'} ) {
             # X-Failed-Recipients: kijitora@example.jp
             my @rcptinhead = split( ',', $mhead->{'x-failed-recipients'} );
-            map { $_ =~ y/ //d } @rcptinhead;
+            map { $_ =~ s/\A[ ]+//; $_ =~ s/[ ]+\z// } @rcptinhead;
             $recipients = scalar @rcptinhead;
 
             for my $e ( @rcptinhead ) {
@@ -367,12 +349,12 @@ sub scan {
     if( scalar @{ $mhead->{'received'} } ) {
         # Get the name of local MTA
         # Received: from marutamachi.example.org (c192128.example.net [192.0.2.128])
-        $localhost0 = $1 if $mhead->{'received'}->[-1] =~ m/from\s([^ ]+) /;
+        $localhost0 = $1 if $mhead->{'received'}->[-1] =~ m/from[ \t]([^ ]+) /;
     }
 
     require Sisimai::String;
-    require Sisimai::RFC3463;
-    require Sisimai::RFC5321;
+    require Sisimai::SMTP::Reply;
+    require Sisimai::SMTP::Status;
 
     for my $e ( @$dscontents ) {
         # Set default values if each value is empty.
@@ -430,7 +412,7 @@ sub scan {
 
         if( ! $e->{'rhost'} ) {
             # Get the remote host name
-            if( $e->{'diagnosis'} =~ m/host\s+([^\s]+)\s\[.+\]:\s/ ) {
+            if( $e->{'diagnosis'} =~ m/host[ \t]+([^ \t]+)[ \t]\[.+\]:[ \t]/ ) {
                 # host neko.example.jp [192.0.2.222]: 550 5.1.1 <kijitora@example.jp>... User Unknown
                 $e->{'rhost'} = $1;
             }
@@ -453,33 +435,29 @@ sub scan {
                 last;
             }
 
-            REASON: while(1) {
-                # Detect the reason of bounce
-                if( $e->{'command'} =~ m/\A(?:HELO|EHLO)\z/ ) {
-                    # HELO | Connected to 192.0.2.135 but my name was rejected.
-                    $e->{'reason'} = 'blocked';
+            # Detect the reason of bounce
+            if( $e->{'command'} =~ m/\A(?:HELO|EHLO)\z/ ) {
+                # HELO | Connected to 192.0.2.135 but my name was rejected.
+                $e->{'reason'} = 'blocked';
 
-                } elsif( $e->{'command'} eq 'MAIL' ) {
-                    # MAIL | Connected to 192.0.2.135 but sender was rejected.
-                    # $e->{'reason'} = 'rejected';
-                    $e->{'reason'} = 'onhold';
+            } elsif( $e->{'command'} eq 'MAIL' ) {
+                # MAIL | Connected to 192.0.2.135 but sender was rejected.
+                # $e->{'reason'} = 'rejected';
+                $e->{'reason'} = 'onhold';
 
-                } else {
-                    # Verify each regular expression of session errors
-                    SESSION: for my $r ( keys %$ReFailure ) {
-                        # Check each regular expression
-                        next unless $e->{'diagnosis'} =~ $ReFailure->{ $r };
-                        $e->{'reason'} = $r;
-                        last(SESSION);
-                    }
-                    last if $e->{'reason'};
+            } else {
+                # Verify each regular expression of session errors
+                SESSION: for my $r ( keys %$ReFailure ) {
+                    # Check each regular expression
+                    next unless $e->{'diagnosis'} =~ $ReFailure->{ $r };
+                    $e->{'reason'} = $r;
+                    last;
+                }
 
-                    if( $e->{'diagnosis'} =~ $ReDelayed ) {
-                        # The reason "expired"
-                        $e->{'reason'} = 'expired';
-                    }
+                unless( $e->{'reason'} ) {
+                    # The reason "expired"
+                    $e->{'reason'} = 'expired' if $e->{'diagnosis'} =~ $ReDelayed;
                 }
-                last;
             }
         }
 
@@ -493,8 +471,8 @@ sub scan {
             #   Diagnostic-Code: smtp; 450 TEMPERROR: retry timeout exceeded
             # The value of "Status:" indicates permanent error but the value
             # of SMTP reply code in Diagnostic-Code: field is "TEMPERROR"!!!!
-            my $sv = Sisimai::RFC3463->getdsn( $e->{'diagnosis'} ) || '';
-            my $rv = Sisimai::RFC5321->getrc( $e->{'diagnosis'} )  || '';
+            my $sv = Sisimai::SMTP::Status->find( $e->{'diagnosis'} );
+            my $rv = Sisimai::SMTP::Reply->find( $e->{'diagnosis'} );
             my $s1 = 0; # First character of Status as integer
             my $r1 = 0; # First character of SMTP reply code as integer
             my $v1 = 0;
@@ -507,11 +485,11 @@ sub scan {
                     $r1 = substr( $rv, 0, 1 );
                     if( $r1 == 4 ) {
                         # Get the internal DSN(temporary error)
-                        $sv = Sisimai::RFC3463->status( $e->{'reason'}, 't', 'i' );
+                        $sv = Sisimai::SMTP::Status->code( $e->{'reason'}, 1 );
 
                     } elsif( $r1 == 5 ) {
                         # Get the internal DSN(permanent error)
-                        $sv = Sisimai::RFC3463->status( $e->{'reason'}, 'p', 'i' );
+                        $sv = Sisimai::SMTP::Status->code( $e->{'reason'}, 0 );
                     }
                 }
             }
@@ -542,12 +520,12 @@ sub scan {
                 # Neither Status nor SMTP reply code exist
                 if( $e->{'reason'} =~ m/\A(?:expired|mailboxfull)/ ) {
                     # Set pseudo DSN (temporary error)
-                    $sv = Sisimai::RFC3463->status( $e->{'reason'}, 't', 'i' );
+                    $sv = Sisimai::SMTP::Status->code( $e->{'reason'}, 1 );
                     $e->{'softbounce'} = 1;
 
                 } else {
                     # Set pseudo DSN (permanent error)
-                    $sv = Sisimai::RFC3463->status( $e->{'reason'}, 'p', 'i' );
+                    $sv = Sisimai::SMTP::Status->code( $e->{'reason'}, 0 );
                     $e->{'softbounce'} = 0;
                 }
             }
@@ -603,8 +581,7 @@ azumakuniyuki
 
 =head1 COPYRIGHT
 
-Copyright (C) 2014-2015 azumakuniyuki E<lt>perl.org@azumakuniyuki.orgE<gt>,
-All Rights Reserved.
+Copyright (C) 2014-2015 azumakuniyuki, All rights reserved.
 
 =head1 LICENSE
 
