@@ -53,13 +53,11 @@ sub scan {
     my $recipients = 0;     # (Integer) The number of 'Final-Recipient' header
     my $boundary00 = '';    # (String) Boundary string
     my $endoferror = 0;     # (Integer) Flag for the end of error message
-
     my $v = undef;
-    my $p = '';
 
     $boundary00 = Sisimai::MIME->boundary( $mhead->{'content-type'} );
     $Re1->{'rfc822'} = qr/\A[-]{2}$boundary00[-]{2}\z/ if length $boundary00;
-    $Re1->{'rfc822'} = qr/\A\s*[+]+\s*\z/ unless $Re1->{'rfc822'};
+    $Re1->{'rfc822'} = qr/\A[ \t]*[+]+[ \t]*\z/ unless $Re1->{'rfc822'};
 
     for my $e ( @hasdivided ) {
         # Read each line between $Re1->{'begin'} and $Re1->{'rfc822'}.
@@ -77,16 +75,15 @@ sub scan {
             # After "message/rfc822"
             if( $e =~ m/\A([-0-9A-Za-z]+?)[:][ ]*.+\z/ ) {
                 # Get required headers only
-                my $lhs = $1;
-                my $whs = lc $lhs;
+                my $lhs = lc $1;
 
                 $previousfn = '';
-                next unless exists $RFC822Head->{ $whs };
+                next unless exists $RFC822Head->{ $lhs };
 
-                $previousfn  = lc $lhs;
+                $previousfn  = $lhs;
                 $rfc822part .= $e."\n";
 
-            } elsif( $e =~ m/\A[\s\t]+/ ) {
+            } elsif( $e =~ m/\A[ \t]+/ ) {
                 # Continued line from the previous line
                 next if $rfc822next->{ $previousfn };
                 $rfc822part .= $e."\n" if exists $LongFields->{ $previousfn };
@@ -115,7 +112,7 @@ sub scan {
             #    dummyuser@blabla.xxxxxxxxxxxx.com
             $v = $dscontents->[ -1 ];
 
-            if( $e =~ m/\A\s{4}([^ ]+[@][^ ]+)\z/ ) {
+            if( $e =~ m/\A[ \t]{4}([^ ]+[@][^ ]+)\z/ ) {
                 # The following recipients were affected: 
                 #    dummyuser@blabla.xxxxxxxxxxxx.com
                 if( length $v->{'recipient'} ) {
@@ -150,36 +147,30 @@ sub scan {
                     # Reporting-MTA:      <relay.xxxxxxxxxxxx.com>
                     # MessageName:        <B549996730000.000000000001.0003.mml>
                     # Last-Attempt-Date:  <16:21:07 seg, 22 Dezembro 2014>
-                    if( $e =~ m/\AOriginal Sender:\s+[<](.+)[>]\z/ ) {
+                    if( $e =~ m/\AOriginal Sender:[ \t]+[<](.+)[>]\z/ ) {
                         # Original Sender:    <originalsender@example.com>
                         # Use this line instead of "From" header of the original
                         # message.
                         $rfc822part .= sprintf("From: %s\n", $1 );
 
-                    } elsif( $e =~ m/\ASender-MTA:\s+[<](.+)[>]\z/ ) {
+                    } elsif( $e =~ m/\ASender-MTA:[ \t]+[<](.+)[>]\z/ ) {
                         # Sender-MTA:         <10.11.12.13>
                         $v->{'lhost'} = $1;
 
-                    } elsif( $e =~ m/\AReporting-MTA:\s+[<](.+)[>]\z/ ) {
+                    } elsif( $e =~ m/\AReporting-MTA:[ \t]+[<](.+)[>]\z/ ) {
                         # Reporting-MTA:      <relay.xxxxxxxxxxxx.com>
                         $v->{'rhost'} = $1;
                     }
                 }
-            } 
+            }
         } # End of if: rfc822
-
-    } continue {
-        # Save the current line for the next loop
-        $p = $e;
-        $e = '';
     }
 
     return undef unless $recipients;
     require Sisimai::String;
-    require Sisimai::RFC3463;
+    require Sisimai::SMTP::Status;
 
     for my $e ( @$dscontents ) {
-        # Set default values if each value is empty.
         $e->{'agent'} = __PACKAGE__->smtpagent;
 
         if( scalar @{ $mhead->{'received'} } ) {
@@ -189,11 +180,10 @@ sub scan {
             $e->{'rhost'} ||= pop @{ Sisimai::RFC5322->received( $r->[-1] ) };
         }
         $e->{'diagnosis'} = Sisimai::String->sweep( $e->{'diagnosis'} );
-        $e->{'status'}    = Sisimai::RFC3463->getdsn( $e->{'diagnosis'} );
+        $e->{'status'}    = Sisimai::SMTP::Status->find( $e->{'diagnosis'} );
         $e->{'spec'}      = $e->{'reason'} eq 'mailererror' ? 'X-UNIX' : 'SMTP';
         $e->{'action'}    = 'failed' if $e->{'status'} =~ m/\A[45]/;
-
-    } # end of for()
+    }
 
     return { 'ds' => $dscontents, 'rfc822' => $rfc822part };
 }
@@ -243,8 +233,7 @@ azumakuniyuki
 
 =head1 COPYRIGHT
 
-Copyright (C) 2014-2015 azumakuniyuki E<lt>perl.org@azumakuniyuki.orgE<gt>,
-All Rights Reserved.
+Copyright (C) 2014-2015 azumakuniyuki, All rights reserved.
 
 =head1 LICENSE
 
