@@ -12,7 +12,7 @@ my $Re0 = {
 my $Re1 = {
     'begin'    => qr/\AThis report relates to a message you sent with the following header fields:/,
     'endof'    => qr/\A__END_OF_EMAIL_MESSAGE__\z/,
-    'rfc822'   => qr!\A(?:Content-type:\s*message/rfc822|Return-path:\s*)!x,
+    'rfc822'   => qr!\A(?:Content-type:[ \t]*message/rfc822|Return-path:[ \t]*)!x,
 };
 
 my $ReFailure = {
@@ -50,7 +50,6 @@ sub scan {
     return undef unless $match;
 
     require Sisimai::Address;
-
     my $dscontents = []; push @$dscontents, __PACKAGE__->DELIVERYSTATUS;
     my @hasdivided = split( "\n", $$mbody );
     my $rfc822next = { 'from' => 0, 'to' => 0, 'subject' => 0 };
@@ -58,9 +57,7 @@ sub scan {
     my $previousfn = '';    # (String) Previous field name
     my $readcursor = 0;     # (Integer) Points the current cursor position
     my $recipients = 0;     # (Integer) The number of 'Final-Recipient' header
-
     my $v = undef;
-    my $p = '';
 
     for my $e ( @hasdivided ) {
         # Read each line between $Re1->{'begin'} and $Re1->{'rfc822'}.
@@ -84,16 +81,14 @@ sub scan {
             # After "message/rfc822"
             if( $e =~ m/\A([-0-9A-Za-z]+?)[:][ ]*.+\z/ ) {
                 # Get required headers only
-                my $lhs = $1;
-                my $whs = lc $lhs;
-
+                my $lhs = lc $1;
                 $previousfn = '';
-                next unless exists $RFC822Head->{ $whs };
+                next unless exists $RFC822Head->{ $lhs };
 
-                $previousfn  = lc $lhs;
+                $previousfn  = $lhs;
                 $rfc822part .= $e."\n";
 
-            } elsif( $e =~ m/\A[\s\t]+/ ) {
+            } elsif( $e =~ m/\A[ \t]+/ ) {
                 # Continued line from the previous line
                 next if $rfc822next->{ $previousfn };
                 $rfc822part .= $e."\n" if exists $LongFields->{ $previousfn };
@@ -130,7 +125,7 @@ sub scan {
             #   Remote system: dns;mx.example.jp (TCP|17.111.174.67|47323|192.0.2.225|25) (6jo.example.jp ESMTP SENDMAIL-VM)
             $v = $dscontents->[ -1 ];
 
-            if( $e =~ m/\A\s+Recipient address:\s*([^ ]+[@][^ ]+)\z/ ) {
+            if( $e =~ m/\A[ \t]+Recipient address:[ \t]*([^ ]+[@][^ ]+)\z/ ) {
                 #   Recipient address: kijitora@example.jp
                 if( length $v->{'recipient'} ) {
                     # There are multiple recipient addresses in the message body.
@@ -140,36 +135,35 @@ sub scan {
                 $v->{'recipient'} = Sisimai::Address->s3s4( $1 );
                 $recipients++;
 
-            } elsif( $e =~ m/\A\s+Original address:\s*([^ ]+[@][^ ]+)\z/ ) {
+            } elsif( $e =~ m/\A[ \t]+Original address:[ \t]*([^ ]+[@][^ ]+)\z/ ) {
                 #   Original address: kijitora@example.jp
                 $v->{'recipient'} = Sisimai::Address->s3s4( $1 );
 
-            } elsif( $e =~ m/\A\s+Date:\s*(.+)\z/ ) {
+            } elsif( $e =~ m/\A[ \t]+Date:[ \t]*(.+)\z/ ) {
                 #   Date: Fri, 21 Nov 2014 23:34:45 +0900
                 $v->{'date'} = $1;
 
-            } elsif( $e =~ m/\A\s+Reason:\s*(.+)\z/ ) {
+            } elsif( $e =~ m/\A[ \t]+Reason:[ \t]*(.+)\z/ ) {
                 #   Reason: Remote SMTP server has rejected address
                 $v->{'diagnosis'} = $1;
 
-            } elsif( $e =~ m/\A\s+Diagnostic code:\s*([^ ]+);(.+)\z/ ) {
+            } elsif( $e =~ m/\A[ \t]+Diagnostic code:[ \t]*([^ ]+);(.+)\z/ ) {
                 #   Diagnostic code: smtp;550 5.1.1 <kijitora@example.jp>... User Unknown
                 $v->{'spec'} = uc $1;
                 $v->{'diagnosis'} = $2;
 
-            } elsif( $e =~ m/\A\s+Remote system:\s*dns;([^ ]+)\s*([^ ]+)\s*.+\z/ ) {
+            } elsif( $e =~ m/\A[ \t]+Remote system:[ \t]*dns;([^ ]+)[ \t]*([^ ]+)[ \t]*.+\z/ ) {
                 #   Remote system: dns;mx.example.jp (TCP|17.111.174.67|47323|192.0.2.225|25)
                 #     (6jo.example.jp ESMTP SENDMAIL-VM)
-                my $r = $1; # remote host
-                my $s = $2; # smtp session
+                my $remotehost = $1; # remote host
+                my $sessionlog = $2; # smtp session
+                $v->{'rhost'} = $remotehost;
 
-                $v->{'rhost'} = $r;
-
-                if( $s =~ m/\A[(]TCP|(.+)|\d+|(.+)|\d+[)]/ ) {
+                if( $sessionlog =~ m/\A[(]TCP|(.+)|\d+|(.+)|\d+[)]/ ) {
                     # The value does not include ".", use IP address instead.
                     # (TCP|17.111.174.67|47323|192.0.2.225|25)
                     $v->{'lhost'} = $1;
-                    $v->{'rhost'} = $2 unless $r =~ m/[^.]+[.][^.]+/;
+                    $v->{'rhost'} = $2 unless $remotehost =~ m/[^.]+[.][^.]+/;
                 }
 
             } else {
@@ -185,7 +179,7 @@ sub scan {
                 #  (6jo.example.jp ESMTP SENDMAIL-VM)
                 # Diagnostic-code: smtp;550 5.1.1 <kijitora@example.jp>... User Unknown
                 #
-                if( $e =~ m/\A[Ss]tatus:\s*(\d[.]\d[.]\d)\s*[(](.+)[)]\z/ ) {
+                if( $e =~ m/\A[Ss]tatus:[ \t]*(\d[.]\d[.]\d)[ \t]*[(](.+)[)]\z/ ) {
                     # Status: 5.1.1 (Remote SMTP server has rejected address)
                     $v->{'status'} = $1;
                     $v->{'diagnosis'} ||= $2;
@@ -196,25 +190,19 @@ sub scan {
 
                 } elsif( $e =~ m/\A[Rr]eporting-MTA:[ ]*(?:DNS|dns);[ ]*(.+)\z/ ) {
                     # Reporting-MTA: dns;mr21p30im-asmtp004.me.com (tcp-daemon)
-                    my $l = $1;
-                    $v->{'lhost'} ||= $l;
-                    $v->{'lhost'}   = $l unless $v->{'lhost'} =~ m/[^.]+[.][^ ]+/;
+                    my $localhost = $1;
+                    $v->{'lhost'} ||= $localhost;
+                    $v->{'lhost'}   = $localhost unless $v->{'lhost'} =~ m/[^.]+[.][^ ]+/;
                 }
             }
         } # End of if: rfc822
-
-    } continue {
-        # Save the current line for the next loop
-        $p = $e;
-        $e = '';
     }
 
     return undef unless $recipients;
     require Sisimai::String;
-    require Sisimai::RFC3463;
+    require Sisimai::SMTP::Status;
 
     for my $e ( @$dscontents ) {
-        # Set default values if each value is empty.
         $e->{'agent'} = __PACKAGE__->smtpagent;
 
         if( scalar @{ $mhead->{'received'} } ) {
@@ -234,13 +222,12 @@ sub scan {
 
         if( length( $e->{'status'} ) == 0 || $e->{'status'} =~ m/\A\d[.]0[.]0\z/ ) {
             # There is no value of Status header or the value is 5.0.0, 4.0.0
-            my $r = Sisimai::RFC3463->getdsn( $e->{'diagnosis'} );
-            $e->{'status'} = $r if length $r;
+            my $pseudostatus = Sisimai::SMTP::Status->find( $e->{'diagnosis'} );
+            $e->{'status'} = $pseudostatus if length $pseudostatus;
         }
 
         $e->{'action'} = 'failed' if $e->{'status'} =~ m/\A[45]/;
-
-    } # end of for()
+    }
 
     return { 'ds' => $dscontents, 'rfc822' => $rfc822part };
 }
@@ -290,8 +277,7 @@ azumakuniyuki
 
 =head1 COPYRIGHT
 
-Copyright (C) 2014-2015 azumakuniyuki E<lt>perl.org@azumakuniyuki.orgE<gt>,
-All Rights Reserved.
+Copyright (C) 2014-2015 azumakuniyuki, All rights reserved.
 
 =head1 LICENSE
 
