@@ -17,8 +17,8 @@ my $Re1 = {
                 |on[ ].+[ ]program\z    # The Postfix on <os name> program
                 )
             |\w+[ ]Postfix[ ]program\z  # The <name> Postfix program
-            |mail\ssystem\z             # The mail system
-            |\w+\sprogram\z             # The <custmized-name> program
+            |mail[ \t]system\z             # The mail system
+            |\w+[ \t]program\z             # The <custmized-name> program
             )
         |This[ ]is[ ]the[ ](?:
              Postfix[ ]program          # This is the Postfix program
@@ -28,7 +28,7 @@ my $Re1 = {
             )
         )
     }x,
-    'rfc822'  => qr!\AContent-Type:\s*(?:message/rfc822|text/rfc822-headers)\z!x,
+    'rfc822'  => qr!\AContent-Type:[ \t]*(?:message/rfc822|text/rfc822-headers)\z!x,
     'endof'   => qr/\A__END_OF_EMAIL_MESSAGE__\z/,
 };
 
@@ -41,7 +41,7 @@ sub smtpagent   { 'Postfix' }
 sub pattern     { return $Re0 }
 
 sub scan {
-    # Detect an error from Postfix
+    # Parse bounce messages from Postfix
     # @param         [Hash] mhead       Message header of a bounce email
     # @options mhead [String] from      From header
     # @options mhead [String] date      Date header
@@ -57,16 +57,6 @@ sub scan {
     my $mhead = shift // return undef;
     my $mbody = shift // return undef;
 
-    #  ____           _    __ _      
-    # |  _ \ ___  ___| |_ / _(_)_  __
-    # | |_) / _ \/ __| __| |_| \ \/ /
-    # |  __/ (_) \__ \ |_|  _| |>  < 
-    # |_|   \___/|___/\__|_| |_/_/\_\
-    #                                
-    # Pre-Process email headers and the body part of the message which generated
-    # by Postfix e.g.)
-    #   From: MAILER-DAEMON (Mail Delivery System)
-    #   Subject: Undelivered Mail Returned to Sender
     return undef unless $mhead->{'subject'} =~ $Re0->{'subject'};
 
     my $dscontents = []; push @$dscontents, __PACKAGE__->DELIVERYSTATUS;
@@ -109,16 +99,14 @@ sub scan {
             # After "message/rfc822"
             if( $e =~ m/\A([-0-9A-Za-z]+?)[:][ ]*.+\z/ ) {
                 # Get required headers only
-                my $lhs = $1;
-                my $whs = lc $1;
-
+                my $lhs = lc $1;
                 $previousfn = '';
-                next unless exists $RFC822Head->{ $whs };
+                next unless exists $RFC822Head->{ $lhs };
 
-                $previousfn  = lc $lhs;
+                $previousfn  = $lhs;
                 $rfc822part .= $e."\n";
 
-            } elsif( $e =~ m/\A[\s\t]+/ ) {
+            } elsif( $e =~ m/\A[ \t]+/ ) {
                 # Continued line from the previous line
                 next if $rfc822next->{ $previousfn };
                 $rfc822part .= $e."\n" if exists $LongFields->{ $previousfn };
@@ -145,7 +133,7 @@ sub scan {
                 # Last-Attempt-Date: Fri, 14 Feb 2014 12:30:08 -0500
                 $v = $dscontents->[ -1 ];
 
-                if( $e =~ m/\A[Ff]inal-[Rr]ecipient:[ ]*rfc822;[ ]*(.+)\z/ ) {
+                if( $e =~ m/\A[Ff]inal-[Rr]ecipient:[ ]*(?:RFC|rfc)822;[ ]*(.+)\z/ ) {
                     # Final-Recipient: RFC822; userunknown@example.jp
                     if( length $v->{'recipient'} ) {
                         # There are multiple recipient addresses in the message body.
@@ -187,15 +175,13 @@ sub scan {
                     $v->{'date'} = $1;
 
                 } else {
-
                     if( $e =~ m/\A[Dd]iagnostic-[Cc]ode:[ ]*(.+?);[ ]*(.+)\z/ ) {
                         # Diagnostic-Code: SMTP; 550 5.1.1 <userunknown@example.jp>... User Unknown
                         $v->{'spec'} = uc $1;
+                        $v->{'spec'} = 'SMTP' if $v->{'spec'} eq 'X-POSTFIX';
                         $v->{'diagnosis'} = $2;
 
-                        $v->{'spec'} = 'SMTP' if $v->{'spec'} eq 'X-POSTFIX';
-
-                    } elsif( $p =~ m/\A[Dd]iagnostic-[Cc]ode:[ ]*/ && $e =~ m/\A[\s\t]+(.+)\z/ ) {
+                    } elsif( $p =~ m/\A[Dd]iagnostic-[Cc]ode:[ ]*/ && $e =~ m/\A[ \t]+(.+)\z/ ) {
                         # Continued line of the value of Diagnostic-Code header
                         $v->{'diagnosis'} .= ' '.$1;
                         $e = 'Diagnostic-Code: '.$e;
@@ -211,11 +197,11 @@ sub scan {
                 # <userunknown@example.co.jp>: host mx.example.co.jp[192.0.2.153] said: 550
                 # 5.1.1 <userunknown@example.co.jp>... User Unknown (in reply to RCPT TO
                 # command)
-                if( $e =~ m/\s[(]in reply to ([A-Z]{4}).*/ ) {
+                if( $e =~ m/[ \t][(]in reply to ([A-Z]{4}).*/ ) {
                     # 5.1.1 <userunknown@example.co.jp>... User Unknown (in reply to RCPT TO
                     push @commandset, $1;
 
-                } elsif( $e =~ m/([A-Z]{4})\s*.*command[)]\z/ ) {
+                } elsif( $e =~ m/([A-Z]{4})[ \t]*.*command[)]\z/ ) {
                     # to MAIL command)
                     push @commandset, $1;
 
@@ -239,7 +225,7 @@ sub scan {
 
                     } else {
                         # Alternative error message and recipient
-                        if( $e =~ m/\A[<]([^ ]+[@][^ ]+)[>] [(]expanded from [<](.+)[>][)]:\s*(.+)\z/ ) {
+                        if( $e =~ m/\A[<]([^ ]+[@][^ ]+)[>] [(]expanded from [<](.+)[>][)]:[ \t]*(.+)\z/ ) {
                             # <r@example.ne.jp> (expanded from <kijitora@example.org>): user ...
                             $anotherset->{'recipient'} = $1;
                             $anotherset->{'alias'}     = $2;
@@ -253,7 +239,7 @@ sub scan {
                         } else {
                             # Get error message continued from the previous line
                             next unless $anotherset->{'diagnosis'};
-                            if( $e =~ m/\A\s{4}(.+)\z/ ) {
+                            if( $e =~ m/\A[ \t]{4}(.+)\z/ ) {
                                 #    host mx.example.jp said:...
                                 $anotherset->{'diagnosis'} .= ' '.$e;
                             }
@@ -266,7 +252,6 @@ sub scan {
     } continue {
         # Save the current line for the next loop
         $p = $e;
-        $e = '';
     }
 
     unless( $recipients ) {
@@ -277,10 +262,11 @@ sub scan {
             $recipients++;
         }
     }
-
     return undef unless $recipients;
+
     require Sisimai::String;
-    require Sisimai::RFC3463;
+    require Sisimai::SMTP;
+    require Sisimai::SMTP::Status;
 
     for my $e ( @$dscontents ) {
         # Set default values if each value is empty.
@@ -309,10 +295,10 @@ sub scan {
 
         if( length( $e->{'status'} ) == 0 || $e->{'status'} =~ m/\A\d[.]0[.]0\z/ ) {
             # There is no value of Status header or the value is 5.0.0, 4.0.0
-            my $r = Sisimai::RFC3463->getdsn( $e->{'diagnosis'} );
+            my $r = Sisimai::SMTP::Status->find( $e->{'diagnosis'} );
             $e->{'status'} = $r if length $r;
         }
-        $e->{'softbounce'} = Sisimai::RFC3463->is_softbounce( $e->{'status'} );
+        # $e->{'softbounce'} = Sisimai::SMTP->is_softbounce( $e->{'status'} );
     }
     return { 'ds' => $dscontents, 'rfc822' => $rfc822part };
 }
@@ -360,8 +346,7 @@ azumakuniyuki
 
 =head1 COPYRIGHT
 
-Copyright (C) 2014-2015 azumakuniyuki E<lt>perl.org@azumakuniyuki.orgE<gt>,
-All Rights Reserved.
+Copyright (C) 2014-2015 azumakuniyuki, All rights reserved.
 
 =head1 LICENSE
 
