@@ -25,12 +25,12 @@ my $Re0 = {
 #   savemail.c:498|       putline(buf, fp, m);
 #   savemail.c:499|   (void) fclose(xfile);
 my $Re1 = {
-    'begin'   => qr/\A\s+[-]+ Transcript of session follows [-]+\z/,
+    'begin'   => qr/\A[ \t]+[-]+ Transcript of session follows [-]+\z/,
     'error'   => qr/\A[.]+ while talking to .+[:]\z/,
-    'rfc822'  => qr{\A\s+-----\s(?:
+    'rfc822'  => qr{\A[ \t]+-----[ \t](?:
          Unsent[ ]message[ ]follows
         |No[ ]message[ ]was[ ]collected
-        )\s-----
+        )[ \t]-----
     }x,
     'endof'   => qr/\A__END_OF_EMAIL_MESSAGE__\z/,
 };
@@ -72,9 +72,8 @@ sub scan {
     my @responding = ();    # (Array) Responses from remote server
     my @commandset = ();    # (Array) SMTP command which is sent to remote server
     my $anotherset = {};    # (Ref->Hash) Another error information
-
+    my $errorindex = -1;
     my $v = undef;
-    my $p = '';
 
     for my $e ( @hasdivided ) {
         # Read each line between $Re1->{'begin'} and $Re1->{'rfc822'}.
@@ -98,16 +97,14 @@ sub scan {
             # After "message/rfc822"
             if( $e =~ m/\A([-0-9A-Za-z]+?)[:][ ]*.+\z/ ) {
                 # Get required headers only
-                my $lhs = $1;
-                my $whs = lc $lhs;
-
+                my $lhs = lc $1;
                 $previousfn = '';
-                next unless exists $RFC822Head->{ $whs };
+                next unless exists $RFC822Head->{ $lhs };
 
-                $previousfn  = lc $lhs;
+                $previousfn  = $lhs;
                 $rfc822part .= $e."\n";
 
-            } elsif( $e =~ m/\A[\s\t]+/ ) {
+            } elsif( $e =~ m/\A[ \t]+/ ) {
                 # Continued line from the previous line
                 next if $rfc822next->{ $previousfn };
                 $rfc822part .= $e."\n" if exists $LongFields->{ $previousfn };
@@ -132,15 +129,15 @@ sub scan {
             # 421 example.org (smtp)... Deferred: Connection timed out during user open with example.org
             $v = $dscontents->[ -1 ];
 
-            if( $e =~ m/\A\d{3}\s+[<]([^ ]+[@][^ ]+)[>][.]{3}\s*(.+)\z/ ) {
+            if( $e =~ m/\A\d{3}[ \t]+[<]([^ ]+[@][^ ]+)[>][.]{3}[ \t]*(.+)\z/ ) {
                 # 550 <kijitora@example.org>... User unknown
                 if( length $v->{'recipient'} ) {
                     # There are multiple recipient addresses in the message body.
                     push @$dscontents, __PACKAGE__->DELIVERYSTATUS;
                     $v = $dscontents->[ -1 ];
                 }
-                $v->{'recipient'}  = $1;
-                $v->{'diagnosis'}  = $2;
+                $v->{'recipient'} = $1;
+                $v->{'diagnosis'} = $2;
 
                 if( $responding[ $recipients ] ) {
                     # Concatenate the response of the server and error message
@@ -148,7 +145,7 @@ sub scan {
                 }
                 $recipients++;
 
-            } elsif( $e =~ m/\A[>]{3}\s*([A-Z]{4})\s*/ ) {
+            } elsif( $e =~ m/\A[>]{3}[ \t]*([A-Z]{4})[ \t]*/ ) {
                 # >>> RCPT To:<kijitora@example.org>
                 $commandset[ $recipients ] = $1;
 
@@ -168,20 +165,15 @@ sub scan {
                     next;
                 }
 
-                if( $e =~ m/\A\d{3}\s+.+[.]{3}\s*(.+)\z/ ) {
+                if( $e =~ m/\A\d{3}[ \t]+.+[.]{3}[ \t]*(.+)\z/ ) {
                     # 421 example.org (smtp)... Deferred: Connection timed out during user open with example.org
                     $anotherset->{'diagnosis'} = $1;
                 }
             }
 
         } # End of if: rfc822
-
-    } continue {
-        # Save the current line for the next loop
-        $p = $e;
-        $e = '';
     }
-    return unless $readcursor & $Indicators->{'message-rfc822'};
+    return undef unless $readcursor & $Indicators->{'message-rfc822'};
 
     unless( $recipients ) {
         # Get the recipient address from the original message
@@ -192,13 +184,10 @@ sub scan {
         }
     }
     return undef unless $recipients;
-
     require Sisimai::String;
 
-    my $n = -1;
     for my $e ( @$dscontents ) {
-        # Set default values if each value is empty.
-        $n++;
+        $errorindex++;
 
         if( scalar @{ $mhead->{'received'} } ) {
             # Get localhost and remote host name from Received header.
@@ -209,7 +198,7 @@ sub scan {
 
         $e->{'spec'}  ||= 'SMTP';
         $e->{'agent'}   = __PACKAGE__->smtpagent;
-        $e->{'command'} = $commandset[ $n ] || '';
+        $e->{'command'} = $commandset[ $errorindex ] || '';
 
         if( exists $anotherset->{'diagnosis'} && length $anotherset->{'diagnosis'} ) {
             # Copy alternative error message
@@ -217,7 +206,7 @@ sub scan {
 
         } else {
             # Set server response as a error message
-            $e->{'diagnosis'} ||= $responding[ $n ];
+            $e->{'diagnosis'} ||= $responding[ $errorindex ];
         }
         $e->{'diagnosis'} = Sisimai::String->sweep( $e->{'diagnosis'} );
 
@@ -276,8 +265,7 @@ azumakuniyuki
 
 =head1 COPYRIGHT
 
-Copyright (C) 2014-2015 azumakuniyuki E<lt>perl.org@azumakuniyuki.orgE<gt>,
-All Rights Reserved.
+Copyright (C) 2014-2015 azumakuniyuki, All rights reserved.
 
 =head1 LICENSE
 
