@@ -5,13 +5,13 @@ use strict;
 use warnings;
 
 my $Re0 = {
-    'from'     => qr/["]Mail Deliver System["] /,
-    'subject'  => qr/\AReturned Mail: /,
+    'from'    => qr/["]Mail Deliver System["] /,
+    'subject' => qr/\AReturned Mail: /,
 };
 my $Re1 = {
-    'begin'    => qr/\AThe original message was received at (.+)\z/,
-    'endof'    => qr/\A__END_OF_EMAIL_MESSAGE__\z/,
-    'rfc822'   => qr/\AReceived: from \d+[.]\d+[.]\d+[.]\d/,
+    'begin'   => qr/\AThe original message was received at (.+)\z/,
+    'endof'   => qr/\A__END_OF_EMAIL_MESSAGE__\z/,
+    'rfc822'  => qr/\AReceived: from \d+[.]\d+[.]\d+[.]\d/,
 };
 
 my $Indicators = __PACKAGE__->INDICATORS;
@@ -49,10 +49,8 @@ sub scan {
     my $previousfn = '';    # (String) Previous field name
     my $readcursor = 0;     # (Integer) Points the current cursor position
     my $recipients = 0;     # (Integer) The number of 'Final-Recipient' header
-    my $datestring = '';
-
+    my $datestring = '';    # (String) Date string
     my $v = undef;
-    my $p = '';
 
     for my $e ( @hasdivided ) {
         # Read each line between $Re1->{'begin'} and $Re1->{'rfc822'}.
@@ -76,16 +74,14 @@ sub scan {
             # After "message/rfc822"
             if( $e =~ m/\A([-0-9A-Za-z]+?)[:][ ]*.+\z/ ) {
                 # Get required headers only
-                my $lhs = $1;
-                my $whs = lc $lhs;
-
+                my $lhs = lc $1;
                 $previousfn = '';
-                next unless exists $RFC822Head->{ $whs };
+                next unless exists $RFC822Head->{ $lhs };
 
-                $previousfn  = lc $lhs;
+                $previousfn  = $lhs;
                 $rfc822part .= $e."\n";
 
-            } elsif( $e =~ m/\A[\s\t]+/ ) {
+            } elsif( $e =~ m/\A[ \t]+/ ) {
                 # Continued line from the previous line
                 next if $rfc822next->{ $previousfn };
                 $rfc822part .= $e."\n" if exists $LongFields->{ $previousfn };
@@ -110,7 +106,7 @@ sub scan {
             # kijitora@example.co.jp [User unknown]
             $v = $dscontents->[ -1 ];
 
-            if( $e =~ m/\A([^ ]+?[@][^ ]+?)\s+\[(.+)\]\z/ ) {
+            if( $e =~ m/\A([^ ]+?[@][^ ]+?)[ \t]+\[(.+)\]\z/ ) {
                 # kijitora@example.co.jp [User unknown]
                 if( length $v->{'recipient'} ) {
                     # There are multiple recipient addresses in the message body.
@@ -126,19 +122,13 @@ sub scan {
                 $datestring = $1;
             }
         } # End of if: rfc822
-
-    } continue {
-        # Save the current line for the next loop
-        $p = $e;
-        $e = '';
     }
 
     return undef unless $recipients;
     require Sisimai::String;
-    require Sisimai::RFC3463;
+    require Sisimai::SMTP::Status;
 
     for my $e ( @$dscontents ) {
-        # Set default values if each value is empty.
         $e->{'agent'} = __PACKAGE__->smtpagent;
 
         if( scalar @{ $mhead->{'received'} } ) {
@@ -148,12 +138,11 @@ sub scan {
             $e->{'rhost'} ||= pop @{ Sisimai::RFC5322->received( $r->[-1] ) };
         }
         $e->{'diagnosis'} = Sisimai::String->sweep( $e->{'diagnosis'} );
-        $e->{'status'}    = Sisimai::RFC3463->getdsn( $e->{'diagnosis'} );
+        $e->{'status'}    = Sisimai::SMTP::Status->find( $e->{'diagnosis'} );
         $e->{'spec'}      = $e->{'reason'} eq 'mailererror' ? 'X-UNIX' : 'SMTP';
         $e->{'action'}    = 'failed' if $e->{'status'} =~ m/\A[45]/;
         $e->{'date'}      = $datestring || '';
-
-    } # end of for()
+    }
 
     return { 'ds' => $dscontents, 'rfc822' => $rfc822part };
 }
@@ -173,7 +162,7 @@ Sisimai::MTA::X1 - bounce mail parser class for C<X1>.
 
 =head1 DESCRIPTION
 
-Sisimai::MTA::X1 parses a bounce email which created by Unknown MTA #1.  Methods
+Sisimai::MTA::X1 parses a bounce email which created by Unknown MTA #1. Methods
 in the module are called from only Sisimai::Message.
 
 =head1 CLASS METHODS
@@ -201,8 +190,7 @@ azumakuniyuki
 
 =head1 COPYRIGHT
 
-Copyright (C) 2014-2015 azumakuniyuki E<lt>perl.org@azumakuniyuki.orgE<gt>,
-All Rights Reserved.
+Copyright (C) 2014-2015 azumakuniyuki, All rights reserved.
 
 =head1 LICENSE
 
