@@ -6,10 +6,10 @@ use warnings;
 
 my $Re0 = {
     'subject'  => qr{\A(?:
-                      failure[ ]notice
-                     |Permanent[ ]Delivery[ ]Failure
-                     )
-                    }xi,
+         failure[ ]notice
+        |Permanent[ ]Delivery[ ]Failure
+        )
+    }xi,
     'received' => qr/\A[(]qmail[ ]+\d+[ ]+invoked[ ]+for[ ]+bounce[)]/,
 };
 #  qmail-remote.c:248|    if (code >= 500) {
@@ -23,59 +23,52 @@ my $Re0 = {
 # MTA module for qmail clones
 my $Re1 = {
     'begin'  => qr{\A(?>
-                     He/Her[ ]is[ ]not.+[ ]user
-                    |Su[ ]mensaje[ ]no[ ]pudo[ ]ser[ ]entregado
-                    |This[ ]is[ ]the[ ](?:
-                         machine[ ]generated[ ]message[ ]from[ ]mail[ ]service
-                        |mail[ ]delivery[ ]agent[ ]at
-                        )
-                    |Unable[ ]to[ ]deliver[ ]message[ ]to[ ]the[ ]following[ ]address
-                    |Unfortunately,[ ]your[ ]mail[ ]was[ ]not[ ]delivered[ ]to[ ]the[ ]following[ ]address:
-                    |Your[ ](?:
-                         mail[ ]message[ ]to[ ]the[ ]following[ ]address
-                        |message[ ]to[ ]the[ ]following[ ]addresses
-                        )
-                    |We're[ ]sorry[.]
-                    )
-                }ix,
+         He/Her[ ]is[ ]not.+[ ]user
+        |Hi[.][ ].+[ ]unable[ ]to[ ]deliver[ ]your[ ]message[ ]to[ ]the[ ]following[ ]addresses
+        |Su[ ]mensaje[ ]no[ ]pudo[ ]ser[ ]entregado
+        |This[ ]is[ ]the[ ](?:
+             machine[ ]generated[ ]message[ ]from[ ]mail[ ]service
+            |mail[ ]delivery[ ]agent[ ]at
+            )
+        |Unable[ ]to[ ]deliver[ ]message[ ]to[ ]the[ ]following[ ]address
+        |Unfortunately,[ ]your[ ]mail[ ]was[ ]not[ ]delivered[ ]to[ ]the[ ]following[ ]address:
+        |Your[ ](?:
+             mail[ ]message[ ]to[ ]the[ ]following[ ]address
+            |message[ ]to[ ]the[ ]following[ ]addresses
+            )
+        |We're[ ]sorry[.]
+        )
+    }ix,
     'rfc822' => qr{\A(?:
-                     ---[ ]Below[ ]this[ ]line[ ]is[ ]a[ ]copy[ ]of[ ]the[ ]message[.]
-                    |---[ ]Original[ ]message[ ]follows[.]
-                    )
-                }xi,
+         ---[ ]Below[ ]this[ ]line[ ]is[ ]a[ ]copy[ ]of[ ]the[ ]message[.]
+        |---[ ]Original[ ]message[ ]follows[.]
+        )
+    }xi,
     'error'  => qr/\ARemote host said:/,
     'sorry'  => qr/\A[Ss]orry[,.][ ]/,
     'endof'  => qr/\A__END_OF_EMAIL_MESSAGE__\z/,
 };
 
 my $ReSMTP = {
-    'conn'  => qr{
-        # Error text regular expressions which defined in qmail-remote.c
-        # qmail-remote.c:225|  if (smtpcode() != 220) quit("ZConnected to "," but greeting failed");
-        (?:Error:)?Connected[ ]to[ ].+[ ]but[ ]greeting[ ]failed[.]
-    }x,
-    'ehlo' => qr{
-        # qmail-remote.c:231|  if (smtpcode() != 250) quit("ZConnected to "," but my name was rejected");
-        (?:Error:)?Connected[ ]to[ ].+[ ]but[ ]my[ ]name[ ]was[ ]rejected[.]
-    }x,
-    'mail'  => qr{
-        # qmail-remote.c:238|  if (code >= 500) quit("DConnected to "," but sender was rejected");
-        # reason = rejected
-        (?:Error:)?Connected[ ]to[ ].+[ ]but[ ]sender[ ]was[ ]rejected[.]
-    }x,
-    'rcpt'  => qr{
-        # qmail-remote.c:249|  out("h"); outhost(); out(" does not like recipient.\n");
-        # qmail-remote.c:253|  out("s"); outhost(); out(" does not like recipient.\n");
-        # reason = userunknown
-        (?:Error:)?.+[ ]does[ ]not[ ]like[ ]recipient[.]
-    },
+    # Error text regular expressions which defined in qmail-remote.c
+    # qmail-remote.c:225|  if (smtpcode() != 220) quit("ZConnected to "," but greeting failed");
+    'conn'  => qr/(?:Error:)?Connected[ ]to[ ].+[ ]but[ ]greeting[ ]failed[.]/x,
+    # qmail-remote.c:231|  if (smtpcode() != 250) quit("ZConnected to "," but my name was rejected");
+    'ehlo'  => qr/(?:Error:)?Connected[ ]to[ ].+[ ]but[ ]my[ ]name[ ]was[ ]rejected[.]/x,
+    # qmail-remote.c:238|  if (code >= 500) quit("DConnected to "," but sender was rejected");
+    # reason = rejected
+    'mail'  => qr/(?:Error:)?Connected[ ]to[ ].+[ ]but[ ]sender[ ]was[ ]rejected[.]/x,
+    # qmail-remote.c:249|  out("h"); outhost(); out(" does not like recipient.\n");
+    # qmail-remote.c:253|  out("s"); outhost(); out(" does not like recipient.\n");
+    # reason = userunknown
+    'rcpt'  => qr/(?:Error:)?.+[ ]does[ ]not[ ]like[ ]recipient[.]/x,
+    # qmail-remote.c:265|  if (code >= 500) quit("D"," failed on DATA command");
+    # qmail-remote.c:266|  if (code >= 400) quit("Z"," failed on DATA command");
+    # qmail-remote.c:271|  if (code >= 500) quit("D"," failed after I sent the message");
+    # qmail-remote.c:272|  if (code >= 400) quit("Z"," failed after I sent the message");
     'data'  => qr{(?:
          (?:Error:)?.+[ ]failed[ ]on[ ]DATA[ ]command[.]
-        # qmail-remote.c:265|  if (code >= 500) quit("D"," failed on DATA command");
-        # qmail-remote.c:266|  if (code >= 400) quit("Z"," failed on DATA command");
         |(?:Error:)?.+[ ]failed[ ]after[ ]I[ ]sent[ ]the[ ]message[.]
-        # qmail-remote.c:271|  if (code >= 500) quit("D"," failed after I sent the message");
-        # qmail-remote.c:272|  if (code >= 400) quit("Z"," failed after I sent the message");
         )
     }x,
 };
@@ -102,10 +95,10 @@ my $ReLDAP = {
         |Permanent[ ]error[ ]while[ ]executing[ ]qmail[-]forward    # 5.4.4
         |Temporary[ ](?:
              error[ ](?:
-                 in[ ]automatic[ ]homedir[ ]creation            # 4.3.0 or 5.3.0
-                |while[ ]executing[ ]qmail[-]forward            # 4.4.4
+                 in[ ]automatic[ ]homedir[ ]creation    # 4.3.0 or 5.3.0
+                |while[ ]executing[ ]qmail[-]forward    # 4.4.4
                 )
-            |failure[ ]in[ ]LDAP[ ]lookup                       # 4.4.3
+            |failure[ ]in[ ]LDAP[ ]lookup               # 4.4.3
             )
         |Unable[ ]to[ ](?:
              contact[ ]LDAP[ ]server                            # 4.4.3
@@ -116,36 +109,26 @@ my $ReLDAP = {
 };
 
 # userunknown + expired
-my $ReOnHold = qr/\A[^ ]+ does not like recipient[.]\s+.+this message has been in the queue too long[.]\z/;
+my $ReOnHold  = qr/\A[^ ]+ does not like recipient[.][ \t]+.+this message has been in the queue too long[.]\z/;
 
-my $ReCommand = qr/
-    # qmail-remote-fallback.patch
-    Sorry,[ ]no[ ]SMTP[ ]connection[ ]got[ ]far[ ]enough;[ ]most[ ]progress[ ]was[ ]([A-Z]{4})[ ]
-/x;
-
-my $ReSession = {
-    # 'onhold' => qr//,
+# qmail-remote-fallback.patch
+my $ReCommand = qr/Sorry,[ ]no[ ]SMTP[ ]connection[ ]got[ ]far[ ]enough;[ ]most[ ]progress[ ]was[ ]([A-Z]{4})[ ]/x;
+my $ReFailure = {
+    # qmail-local.c:589|  strerr_die1x(100,"Sorry, no mailbox here by that name. (#5.1.1)");
+    # qmail-remote.c:253|  out("s"); outhost(); out(" does not like recipient.\n");
     'userunknown' => qr{(?:
-        # qmail-local.c:589|  strerr_die1x(100,"Sorry, no mailbox here by that name. (#5.1.1)");
          no[ ]mailbox[ ]here[ ]by[ ]that[ ]name
-        # qmail-remote.c:253|  out("s"); outhost(); out(" does not like recipient.\n");
         |[ ]does[ ]not[ ]like[ ]recipient[.]
         )
     }x,
-    'mailboxfull' => qr{
-        # error_str.c:192|  X(EDQUOT,"disk quota exceeded")
-        disk[ ]quota[ ]exceeded
-    }x,
-    'mesgtoobig' => qr{
-        # qmail-qmtpd.c:233| ... result = "Dsorry, that message size exceeds my databytes limit (#5.3.4)";
-        # qmail-smtpd.c:391| ... out("552 sorry, that message size exceeds my databytes limit (#5.3.4)\r\n"); return;
-        Message[ ]size[ ]exceeds[ ]fixed[ ]maximum[ ]message[ ]size:
-    }x,
-    'hostunknown' => qr{
-        # qmail-remote.c:68|  Sorry, I couldn't find any host by that name. (#4.1.2)\n"); zerodie();
-        # qmail-remote.c:78|  Sorry, I couldn't find any host named ");
-        \ASorry[,][ ]I[ ]couldn[']t[ ]find[ ]any[ ]host[ ]
-    }x,
+    # error_str.c:192|  X(EDQUOT,"disk quota exceeded")
+    'mailboxfull' => qr/disk[ ]quota[ ]exceeded/x,
+    # qmail-qmtpd.c:233| ... result = "Dsorry, that message size exceeds my databytes limit (#5.3.4)";
+    # qmail-smtpd.c:391| ... out("552 sorry, that message size exceeds my databytes limit (#5.3.4)\r\n"); return;
+    'mesgtoobig'  => qr/Message[ ]size[ ]exceeds[ ]fixed[ ]maximum[ ]message[ ]size:/x,
+    # qmail-remote.c:68|  Sorry, I couldn't find any host by that name. (#4.1.2)\n"); zerodie();
+    # qmail-remote.c:78|  Sorry, I couldn't find any host named ");
+    'hostunknown' => qr/\ASorry[,][ ]I[ ]couldn[']t[ ]find[ ]any[ ]host[ ]/x,
     'systemerror' => qr{(?>
          bad[ ]interpreter:[ ]No[ ]such[ ]file[ ]or[ ]directory
         |system[ ]error
@@ -159,14 +142,11 @@ my $ReSession = {
             or[ ]A[ ]for[ ]that[ ]host
         )
     }x,
-    'systemfull' => 
-        qr/Requested action not taken: mailbox unavailable [(]not enough free space[)]/,
+    'systemfull' => qr/Requested action not taken: mailbox unavailable [(]not enough free space[)]/,
 };
 
-my $ReDelayed = qr{
-    # qmail-send.c:922| ... (&dline[c],"I'm not going to try again; this message has been in the queue too long.\n")) nomem();
-    this[ ]message[ ]has[ ]been[ ]in[ ]the[ ]queue[ ]too[ ]long[.]\z
-}x;
+# qmail-send.c:922| ... (&dline[c],"I'm not going to try again; this message has been in the queue too long.\n")) nomem();
+my $ReDelayed = qr{this[ ]message[ ]has[ ]been[ ]in[ ]the[ ]queue[ ]too[ ]long[.]\z}x;
 
 my $Indicators = __PACKAGE__->INDICATORS;
 my $LongFields = Sisimai::RFC5322->LONGFIELDS;
@@ -209,9 +189,7 @@ sub scan {
     my $previousfn = '';    # (String) Previous field name
     my $readcursor = 0;     # (Integer) Points the current cursor position
     my $recipients = 0;     # (Integer) The number of 'Final-Recipient' header
-
     my $v = undef;
-    my $p = '';
 
     for my $e ( @hasdivided ) {
         # Read each line between $Re1->{'begin'} and $Re1->{'rfc822'}.
@@ -235,16 +213,14 @@ sub scan {
             # After "message/rfc822"
             if( $e =~ m/\A([-0-9A-Za-z]+?)[:][ ]*.+\z/ ) {
                 # Get required headers only
-                my $lhs = $1;
-                my $whs = lc $lhs;
-
+                my $lhs = lc $1;
                 $previousfn = '';
-                next unless exists $RFC822Head->{ $whs };
+                next unless exists $RFC822Head->{ $lhs };
 
-                $previousfn  = lc $lhs;
+                $previousfn  = $lhs;
                 $rfc822part .= $e."\n";
 
-            } elsif( $e =~ m/\A[\s\t]+/ ) {
+            } elsif( $e =~ m/\A[ \t]+/ ) {
                 # Continued line from the previous line
                 next if $rfc822next->{ $previousfn };
                 $rfc822part .= $e."\n" if exists $LongFields->{ $previousfn };
@@ -271,7 +247,7 @@ sub scan {
                 # This is a permanent error; I've given up. Sorry it didn't work out.
                 $v->{'softbounce'} = 0;
 
-            } elsif( $e =~ m/\A(?:To[ ]*:)?[<](.+[@].+)[>]:\s*\z/ ) {
+            } elsif( $e =~ m/\A(?:To[ ]*:)?[<](.+[@].+)[>]:[ \t]*\z/ ) {
                 # <kijitora@example.jp>:
                 if( length $v->{'recipient'} ) {
                     # There are multiple recipient addresses in the message body.
@@ -291,19 +267,13 @@ sub scan {
                 $v->{'rhost'} = $1 if $e =~ $ReHost;
             }
         } # End of if: rfc822
-
-    } continue {
-        # Save the current line for the next loop
-        $p = $e;
-        $e = '';
     }
 
     return undef unless $recipients;
     require Sisimai::String;
-    require Sisimai::RFC3463;
+    require Sisimai::SMTP::Status;
 
     for my $e ( @$dscontents ) {
-        # Set default values if each value is empty.
         $e->{'agent'} = __PACKAGE__->smtpagent;
 
         if( scalar @{ $mhead->{'received'} } ) {
@@ -315,75 +285,71 @@ sub scan {
         $e->{'diagnosis'} = Sisimai::String->sweep( $e->{'diagnosis'} );
 
         if( ! $e->{'command'} ) {
+            # Get the SMTP command name for the session
+            SMTP: for my $r ( keys %$ReSMTP ) {
+                # Verify each regular expression of SMTP commands
+                next unless $e->{'diagnosis'} =~ $ReSMTP->{ $r };
+                $e->{'command'} = uc $r;
+                last;
+            }
 
-            COMMAND: while(1) {
-                # Get the SMTP command name for the session
-                SMTP: for my $r ( keys %$ReSMTP ) {
-                    # Verify each regular expression of SMTP commands
-                    next unless $e->{'diagnosis'} =~ $ReSMTP->{ $r };
-                    $e->{'command'} = uc $r;
-                    last(COMMAND);
-                }
-
+            unless( $e->{'command'} ) {
                 # Verify each regular expression of patches
                 $e->{'command'} = uc $1 if $e->{'diagnosis'} =~ $ReCommand;
-                last;
             }
         }
 
-        REASON: while(1) {
-            # Detect the reason of bounce
-            if( $e->{'command'} eq 'MAIL' ) {
-                # MAIL | Connected to 192.0.2.135 but sender was rejected.
-                $e->{'reason'} = 'rejected';
+        # Detect the reason of bounce
+        if( $e->{'command'} eq 'MAIL' ) {
+            # MAIL | Connected to 192.0.2.135 but sender was rejected.
+            $e->{'reason'} = 'rejected';
 
-            } elsif( $e->{'command'} =~ m/\A(?:HELO|EHLO)\z/ ) {
-                # HELO | Connected to 192.0.2.135 but my name was rejected.
-                $e->{'reason'} = 'blocked';
+        } elsif( $e->{'command'} =~ m/\A(?:HELO|EHLO)\z/ ) {
+            # HELO | Connected to 192.0.2.135 but my name was rejected.
+            $e->{'reason'} = 'blocked';
+
+        } else {
+            # Try to match with each error message in the table
+            if( $e->{'diagnosis'} =~ $ReOnHold ) {
+                # To decide the reason require pattern match with 
+                # Sisimai::Reason::* modules
+                $e->{'reason'} = 'onhold';
 
             } else {
-                # Try to match with each error message in the table
-                if( $e->{'diagnosis'} =~ $ReOnHold ) {
-                    # To decide the reason require pattern match with 
-                    # Sisimai::Reason::* modules
-                    $e->{'reason'} = 'onhold';
-
-                } else {
-
-                    SESSION: for my $r ( keys %$ReSession ) {
-                        # Verify each regular expression of session errors
-                        if( $e->{'alterrors'} ) {
-                            # Check the value of "alterrors"
-                            next unless $e->{'alterrors'} =~ $ReSession->{ $r };
-                            $e->{'reason'} = $r;
-                        }
-                        last(SESSION) if $e->{'reason'};
-
-                        next unless $e->{'diagnosis'} =~ $ReSession->{ $r };
+                SESSION: for my $r ( keys %$ReFailure ) {
+                    # Verify each regular expression of session errors
+                    if( $e->{'alterrors'} ) {
+                        # Check the value of "alterrors"
+                        next unless $e->{'alterrors'} =~ $ReFailure->{ $r };
                         $e->{'reason'} = $r;
-                        last(SESSION);
                     }
+                    last if $e->{'reason'};
 
+                    next unless $e->{'diagnosis'} =~ $ReFailure->{ $r };
+                    $e->{'reason'} = $r;
+                    last;
+                }
+
+                unless( $e->{'reason'} ) {
                     LDAP: for my $r ( keys %$ReLDAP ) {
                         # Verify each regular expression of LDAP errors
                         next unless $e->{'diagnosis'} =~ $ReLDAP->{ $r };
                         $e->{'reason'} = $r;
-                        last(LDAP);
+                        last;
                     }
+                }
 
-                    last if $e->{'reason'};
+                unless( $e->{'reason'} ) {
                     $e->{'reason'} = 'expired' if $e->{'diagnosis'} =~ $ReDelayed;
                 }
             }
-            last;
         }
 
-        $e->{'status'} = Sisimai::RFC3463->getdsn( $e->{'diagnosis'} );
+        $e->{'status'} = Sisimai::SMTP::Status->find( $e->{'diagnosis'} );
         $e->{'spec'}   = $e->{'reason'} eq 'mailererror' ? 'X-UNIX' : 'SMTP';
         $e->{'action'} = 'failed' if $e->{'status'} =~ m/\A[45]/;
         $e->{'command'} ||= '';
-
-    } # end of for()
+    }
 
     return { 'ds' => $dscontents, 'rfc822' => $rfc822part };
 }
@@ -432,8 +398,7 @@ azumakuniyuki
 
 =head1 COPYRIGHT
 
-Copyright (C) 2015 azumakuniyuki E<lt>perl.org@azumakuniyuki.orgE<gt>,
-All Rights Reserved.
+Copyright (C) 2015 azumakuniyuki, All rights reserved.
 
 =head1 LICENSE
 
