@@ -25,33 +25,25 @@ my $Re1 = {
 };
 
 my $ReSMTP = {
-    'conn'  => qr{
-        # Error text regular expressions which defined in qmail-remote.c
-        # qmail-remote.c:225|  if (smtpcode() != 220) quit("ZConnected to "," but greeting failed");
-        (?:Error:)?Connected[ ]to[ ].+[ ]but[ ]greeting[ ]failed[.]
-    }x,
-    'ehlo' => qr{
-        # qmail-remote.c:231|  if (smtpcode() != 250) quit("ZConnected to "," but my name was rejected");
-        (?:Error:)?Connected[ ]to[ ].+[ ]but[ ]my[ ]name[ ]was[ ]rejected[.]
-    }x,
-    'mail'  => qr{
-        # qmail-remote.c:238|  if (code >= 500) quit("DConnected to "," but sender was rejected");
-        # reason = rejected
-        (?:Error:)?Connected[ ]to[ ].+[ ]but[ ]sender[ ]was[ ]rejected[.]
-    }x,
-    'rcpt'  => qr{
-        # qmail-remote.c:249|  out("h"); outhost(); out(" does not like recipient.\n");
-        # qmail-remote.c:253|  out("s"); outhost(); out(" does not like recipient.\n");
-        # reason = userunknown
-        (?:Error:)?.+[ ]does[ ]not[ ]like[ ]recipient[.]
-    },
+    # Error text regular expressions which defined in qmail-remote.c
+    # qmail-remote.c:225|  if (smtpcode() != 220) quit("ZConnected to "," but greeting failed");
+    'conn'  => qr/(?:Error:)?Connected[ ]to[ ].+[ ]but[ ]greeting[ ]failed[.]/x,
+    # qmail-remote.c:231|  if (smtpcode() != 250) quit("ZConnected to "," but my name was rejected");
+    'ehlo' => qr/(?:Error:)?Connected[ ]to[ ].+[ ]but[ ]my[ ]name[ ]was[ ]rejected[.]/x,
+    # qmail-remote.c:238|  if (code >= 500) quit("DConnected to "," but sender was rejected");
+    # reason = rejected
+    'mail'  => qr/(?:Error:)?Connected[ ]to[ ].+[ ]but[ ]sender[ ]was[ ]rejected[.]/x,
+    # qmail-remote.c:249|  out("h"); outhost(); out(" does not like recipient.\n");
+    # qmail-remote.c:253|  out("s"); outhost(); out(" does not like recipient.\n");
+    # reason = userunknown
+    'rcpt'  => qr/(?:Error:)?.+[ ]does[ ]not[ ]like[ ]recipient[.]/x,
+    # qmail-remote.c:265|  if (code >= 500) quit("D"," failed on DATA command");
+    # qmail-remote.c:266|  if (code >= 400) quit("Z"," failed on DATA command");
+    # qmail-remote.c:271|  if (code >= 500) quit("D"," failed after I sent the message");
+    # qmail-remote.c:272|  if (code >= 400) quit("Z"," failed after I sent the message");
     'data'  => qr{(?:
          (?:Error:)?.+[ ]failed[ ]on[ ]DATA[ ]command[.]
-        # qmail-remote.c:265|  if (code >= 500) quit("D"," failed on DATA command");
-        # qmail-remote.c:266|  if (code >= 400) quit("Z"," failed on DATA command");
         |(?:Error:)?.+[ ]failed[ ]after[ ]I[ ]sent[ ]the[ ]message[.]
-        # qmail-remote.c:271|  if (code >= 500) quit("D"," failed after I sent the message");
-        # qmail-remote.c:272|  if (code >= 400) quit("Z"," failed after I sent the message");
         )
     }x,
 };
@@ -92,36 +84,26 @@ my $ReLDAP = {
 };
 
 # userunknown + expired
-my $ReOnHold = qr/\A[^ ]+ does not like recipient[.]\s+.+this message has been in the queue too long[.]\z/;
-
-my $ReCommand = qr/
-    # qmail-remote-fallback.patch
-    Sorry,[ ]no[ ]SMTP[ ]connection[ ]got[ ]far[ ]enough;[ ]most[ ]progress[ ]was[ ]([A-Z]{4})[ ]
-/x;
+my $ReOnHold  = qr/\A[^ ]+ does not like recipient[.][ \t]+.+this message has been in the queue too long[.]\z/;
 
+# qmail-remote-fallback.patch
+my $ReCommand = qr/Sorry,[ ]no[ ]SMTP[ ]connection[ ]got[ ]far[ ]enough;[ ]most[ ]progress[ ]was[ ]([A-Z]{4})[ ]/x;
 my $ReFailure = {
-    # 'onhold' => qr//,
+    # qmail-local.c:589|  strerr_die1x(100,"Sorry, no mailbox here by that name. (#5.1.1)");
+    # qmail-remote.c:253|  out("s"); outhost(); out(" does not like recipient.\n");
     'userunknown' => qr{(?:
-        # qmail-local.c:589|  strerr_die1x(100,"Sorry, no mailbox here by that name. (#5.1.1)");
          no[ ]mailbox[ ]here[ ]by[ ]that[ ]name
-        # qmail-remote.c:253|  out("s"); outhost(); out(" does not like recipient.\n");
         |[ ]does[ ]not[ ]like[ ]recipient[.]
         )
     }x,
-    'mailboxfull' => qr{
-        # error_str.c:192|  X(EDQUOT,"disk quota exceeded")
-        disk[ ]quota[ ]exceeded
-    }x,
-    'mesgtoobig' => qr{
-        # qmail-qmtpd.c:233| ... result = "Dsorry, that message size exceeds my databytes limit (#5.3.4)";
-        # qmail-smtpd.c:391| ... out("552 sorry, that message size exceeds my databytes limit (#5.3.4)\r\n"); return;
-        Message[ ]size[ ]exceeds[ ]fixed[ ]maximum[ ]message[ ]size:
-    }x,
-    'hostunknown' => qr{
-        # qmail-remote.c:68|  Sorry, I couldn't find any host by that name. (#4.1.2)\n"); zerodie();
-        # qmail-remote.c:78|  Sorry, I couldn't find any host named ");
-        \ASorry[,][ ]I[ ]couldn[']t[ ]find[ ]any[ ]host[ ]
-    }x,
+    # error_str.c:192|  X(EDQUOT,"disk quota exceeded")
+    'mailboxfull' => qr/disk[ ]quota[ ]exceeded/x,
+    # qmail-qmtpd.c:233| ... result = "Dsorry, that message size exceeds my databytes limit (#5.3.4)";
+    # qmail-smtpd.c:391| ... out("552 sorry, that message size exceeds my databytes limit (#5.3.4)\r\n"); return;
+    'mesgtoobig' => qr/Message[ ]size[ ]exceeds[ ]fixed[ ]maximum[ ]message[ ]size:/x,
+    # qmail-remote.c:68|  Sorry, I couldn't find any host by that name. (#4.1.2)\n"); zerodie();
+    # qmail-remote.c:78|  Sorry, I couldn't find any host named ");
+    'hostunknown' => qr/\ASorry[,][ ]I[ ]couldn[']t[ ]find[ ]any[ ]host[ ]/x,
     'systemerror' => qr{(?>
          bad[ ]interpreter:[ ]No[ ]such[ ]file[ ]or[ ]directory
         |system[ ]error
@@ -135,14 +117,11 @@ my $ReFailure = {
             or[ ]A[ ]for[ ]that[ ]host
         )
     }x,
-    'systemfull' => 
-        qr/Requested action not taken: mailbox unavailable [(]not enough free space[)]/,
+    'systemfull' => qr/Requested action not taken: mailbox unavailable [(]not enough free space[)]/,
 };
 
-my $ReDelayed = qr{
-    # qmail-send.c:922| ... (&dline[c],"I'm not going to try again; this message has been in the queue too long.\n")) nomem();
-    this[ ]message[ ]has[ ]been[ ]in[ ]the[ ]queue[ ]too[ ]long[.]\z
-}x;
+# qmail-send.c:922| ... (&dline[c],"I'm not going to try again; this message has been in the queue too long.\n")) nomem();
+my $ReDelayed  = qr/this[ ]message[ ]has[ ]been[ ]in[ ]the[ ]queue[ ]too[ ]long[.]\z/x;
 
 my $Indicators = __PACKAGE__->INDICATORS;
 my $LongFields = Sisimai::RFC5322->LONGFIELDS;
@@ -185,9 +164,7 @@ sub scan {
     my $previousfn = '';    # (String) Previous field name
     my $readcursor = 0;     # (Integer) Points the current cursor position
     my $recipients = 0;     # (Integer) The number of 'Final-Recipient' header
-
     my $v = undef;
-    my $p = '';
 
     for my $e ( @hasdivided ) {
         # Read each line between $Re1->{'begin'} and $Re1->{'rfc822'}.
@@ -211,16 +188,14 @@ sub scan {
             # After "message/rfc822"
             if( $e =~ m/\A([-0-9A-Za-z]+?)[:][ ]*.+\z/ ) {
                 # Get required headers only
-                my $lhs = $1;
-                my $whs = lc $lhs;
-
+                my $lhs = lc $1;
                 $previousfn = '';
-                next unless exists $RFC822Head->{ $whs };
+                next unless exists $RFC822Head->{ $lhs };
 
-                $previousfn  = lc $lhs;
+                $previousfn  = $lhs;
                 $rfc822part .= $e."\n";
 
-            } elsif( $e =~ m/\A[\s\t]+/ ) {
+            } elsif( $e =~ m/\A[ \t]+/ ) {
                 # Continued line from the previous line
                 next if $rfc822next->{ $previousfn };
                 $rfc822part .= $e."\n" if exists $LongFields->{ $previousfn };
@@ -243,7 +218,7 @@ sub scan {
             # Giving up on 192.0.2.153.
             $v = $dscontents->[ -1 ];
 
-            if( $e =~ m/\A(?:To[ ]*:)?[<](.+[@].+)[>]:\s*\z/ ) {
+            if( $e =~ m/\A(?:To[ ]*:)?[<](.+[@].+)[>]:[ \t]*\z/ ) {
                 # <kijitora@example.jp>:
                 if( length $v->{'recipient'} ) {
                     # There are multiple recipient addresses in the message body.
@@ -263,16 +238,11 @@ sub scan {
                 $v->{'rhost'} = $1 if $e =~ $ReHost;
             }
         } # End of if: rfc822
-
-    } continue {
-        # Save the current line for the next loop
-        $p = $e;
-        $e = '';
     }
 
     return undef unless $recipients;
     require Sisimai::String;
-    require Sisimai::RFC3463;
+    require Sisimai::SMTP::Status;
 
     for my $e ( @$dscontents ) {
         # Set default values if each value is empty.
@@ -287,75 +257,71 @@ sub scan {
         $e->{'diagnosis'} = Sisimai::String->sweep( $e->{'diagnosis'} );
 
         if( ! $e->{'command'} ) {
+            # Get the SMTP command name for the session
+            SMTP: for my $r ( keys %$ReSMTP ) {
+                # Verify each regular expression of SMTP commands
+                next unless $e->{'diagnosis'} =~ $ReSMTP->{ $r };
+                $e->{'command'} = uc $r;
+                last;
+            }
 
-            COMMAND: while(1) {
-                # Get the SMTP command name for the session
-                SMTP: for my $r ( keys %$ReSMTP ) {
-                    # Verify each regular expression of SMTP commands
-                    next unless $e->{'diagnosis'} =~ $ReSMTP->{ $r };
-                    $e->{'command'} = uc $r;
-                    last(COMMAND);
-                }
-
+            unless( $e->{'command'} ) {
                 # Verify each regular expression of patches
                 $e->{'command'} = uc $1 if $e->{'diagnosis'} =~ $ReCommand;
-                last;
             }
         }
 
-        REASON: while(1) {
-            # Detect the reason of bounce
-            if( $e->{'command'} eq 'MAIL' ) {
-                # MAIL | Connected to 192.0.2.135 but sender was rejected.
-                $e->{'reason'} = 'rejected';
+        # Detect the reason of bounce
+        if( $e->{'command'} eq 'MAIL' ) {
+            # MAIL | Connected to 192.0.2.135 but sender was rejected.
+            $e->{'reason'} = 'rejected';
 
-            } elsif( $e->{'command'} =~ m/\A(?:HELO|EHLO)\z/ ) {
-                # HELO | Connected to 192.0.2.135 but my name was rejected.
-                $e->{'reason'} = 'blocked';
+        } elsif( $e->{'command'} =~ m/\A(?:HELO|EHLO)\z/ ) {
+            # HELO | Connected to 192.0.2.135 but my name was rejected.
+            $e->{'reason'} = 'blocked';
+
+        } else {
+            # Try to match with each error message in the table
+            if( $e->{'diagnosis'} =~ $ReOnHold ) {
+                # To decide the reason require pattern match with 
+                # Sisimai::Reason::* modules
+                $e->{'reason'} = 'onhold';
 
             } else {
-                # Try to match with each error message in the table
-                if( $e->{'diagnosis'} =~ $ReOnHold ) {
-                    # To decide the reason require pattern match with 
-                    # Sisimai::Reason::* modules
-                    $e->{'reason'} = 'onhold';
-
-                } else {
-
-                    SESSION: for my $r ( keys %$ReFailure ) {
-                        # Verify each regular expression of session errors
-                        if( $e->{'alterrors'} ) {
-                            # Check the value of "alterrors"
-                            next unless $e->{'alterrors'} =~ $ReFailure->{ $r };
-                            $e->{'reason'} = $r;
-                        }
-                        last(SESSION) if $e->{'reason'};
-
-                        next unless $e->{'diagnosis'} =~ $ReFailure->{ $r };
+                SESSION: for my $r ( keys %$ReFailure ) {
+                    # Verify each regular expression of session errors
+                    if( $e->{'alterrors'} ) {
+                        # Check the value of "alterrors"
+                        next unless $e->{'alterrors'} =~ $ReFailure->{ $r };
                         $e->{'reason'} = $r;
-                        last(SESSION);
                     }
+                    last if $e->{'reason'};
 
+                    next unless $e->{'diagnosis'} =~ $ReFailure->{ $r };
+                    $e->{'reason'} = $r;
+                    last;
+                }
+
+                unless( $e->{'reason'} ) {
                     LDAP: for my $r ( keys %$ReLDAP ) {
                         # Verify each regular expression of LDAP errors
                         next unless $e->{'diagnosis'} =~ $ReLDAP->{ $r };
                         $e->{'reason'} = $r;
-                        last(LDAP);
+                        last;
                     }
+                }
 
-                    last if $e->{'reason'};
+                unless( $e->{'reason'} ) {
                     $e->{'reason'} = 'expired' if $e->{'diagnosis'} =~ $ReDelayed;
                 }
             }
-            last;
         }
 
-        $e->{'status'} = Sisimai::RFC3463->getdsn( $e->{'diagnosis'} );
+        $e->{'status'} = Sisimai::SMTP::Status->find( $e->{'diagnosis'} );
         $e->{'spec'}   = $e->{'reason'} eq 'mailererror' ? 'X-UNIX' : 'SMTP';
         $e->{'action'} = 'failed' if $e->{'status'} =~ m/\A[45]/;
         $e->{'command'} ||= '';
-
-    } # end of for()
+    }
 
     return { 'ds' => $dscontents, 'rfc822' => $rfc822part };
 }
@@ -403,8 +369,7 @@ azumakuniyuki
 
 =head1 COPYRIGHT
 
-Copyright (C) 2014-2015 azumakuniyuki E<lt>perl.org@azumakuniyuki.orgE<gt>,
-All Rights Reserved.
+Copyright (C) 2014-2015 azumakuniyuki, All rights reserved.
 
 =head1 LICENSE
 
