@@ -21,20 +21,20 @@ Class::Accessor::Lite->mk_ro_accessors( @$roaccessors );
 
 sub new {
     # Constructor of Sisimai::Mail::Mbox
-    # @param    [String] argvs          Path to mbox
+    # @param    [String] argv1          Path to mbox
     # @return   [Sisimai::Mail::Mbox]   Object or Undef if the argument is not 
     #                                   a file or does not exist
     my $class = shift;
-    my $argvs = shift // return undef;
+    my $argv1 = shift // return undef;
     my $param = { 'offset' => 0 };
 
-    return undef unless -f $argvs;
+    return undef unless -f $argv1;
 
-    $param->{'dir'}    = File::Basename::dirname $argvs;
-    $param->{'path'}   = $argvs;
-    $param->{'size'}   = -s $argvs;
-    $param->{'file'}   = File::Basename::basename $argvs;
-    $param->{'handle'} = IO::File->new( $argvs, 'r' );
+    $param->{'dir'}    = File::Basename::dirname $argv1;
+    $param->{'path'}   = $argv1;
+    $param->{'size'}   = -s $argv1;
+    $param->{'file'}   = File::Basename::basename $argv1;
+    $param->{'handle'} = IO::File->new( $argv1, 'r' );
 
     return bless( $param, __PACKAGE__ );
 }
@@ -51,20 +51,20 @@ sub read {
     return undef unless defined $self->{'path'};
     return undef unless -f $self->{'path'};
     return undef unless -T $self->{'path'};
+    return undef unless $self->{'offset'} < $self->{'size'};
 
     eval {
         $seekoffset = 0 if $seekoffset < 0;
-        $filehandle = IO::File->new( $self->{'path'}, 'r' ) unless eof $filehandle;
-
         seek( $filehandle, $seekoffset, 0 );
+
         while( my $r = <$filehandle> ) {
-            # Read an email from the mailbox file
+            # Read the UNIX mbox file from 'From ' to the next 'From '
             last if( length $readbuffer && substr( $r, 0, 5 ) eq 'From ' );
             $readbuffer .= $r;
         }
-        $filehandle->close;
         $seekoffset += length $readbuffer;
         $self->{'offset'} = $seekoffset;
+        $filehandle->close unless $seekoffset < $self->{'size'};
     };
     return $readbuffer;
 }
@@ -151,8 +151,7 @@ azumakuniyuki
 
 =head1 COPYRIGHT
 
-Copyright (C) 2014-2015 azumakuniyuki E<lt>perl.org@azumakuniyuki.orgE<gt>,
-All Rights Reserved.
+Copyright (C) 2014-2015 azumakuniyuki, All rights reserved.
 
 =head1 LICENSE
 
