@@ -6,12 +6,12 @@ use warnings;
 sub text  { 'blocked' }
 sub match {
     # Try to match that the given text and regular expressions
-    # @param    [String] argvs  String to be matched with regular expressions
+    # @param    [String] argv1  String to be matched with regular expressions
     # @return   [Integer]       0: Did not match
     #                           1: Matched
     # @since v4.0.0
     my $class = shift;
-    my $argvs = shift // return undef;
+    my $argv1 = shift // return undef;
     my $regex = qr{(?>
          access[ ]denied[.][ ]IP[ ]name[ ]lookup[ ]failed
         |access[ ]from[ ]ip[ ]address[ ].+[ ]blocked
@@ -62,7 +62,7 @@ sub match {
         )
     }xi;
 
-    return 1 if $argvs =~ $regex;
+    return 1 if $argv1 =~ $regex;
     return 0;
 }
 
@@ -79,16 +79,13 @@ sub true {
     return undef unless ref $argvs eq 'Sisimai::Data';
     return 1 if $argvs->reason eq __PACKAGE__->text;
 
-    require Sisimai::RFC3463;
+    require Sisimai::SMTP::Status;
     my $statuscode = $argvs->deliverystatus // '';
+    my $diagnostic = $argvs->diagnosticcode // '';
+    my $tempreason = Sisimai::SMTP::Status->name( $statuscode );
     my $reasontext = __PACKAGE__->text;
-    my $tempreason = '';
-    my $diagnostic = '';
     my $v = 0;
 
-    $tempreason = Sisimai::RFC3463->reason( $statuscode ) if $statuscode;
-    $diagnostic = $argvs->diagnosticcode // '';
-
     if( $tempreason eq $reasontext ) {
         # Delivery status code points "blocked".
         $v = 1;
@@ -107,7 +104,7 @@ __END__
 
 =head1 NAME
 
-Sisimai::Reason::Blocked - Bounce reason is C<blocked> or not.
+Sisimai::Reason::Blocked - Bounce reason is "blocked" or not.
 
 =head1 SYNOPSIS
 
@@ -116,11 +113,11 @@ Sisimai::Reason::Blocked - Bounce reason is C<blocked> or not.
 
 =head1 DESCRIPTION
 
-Sisimai::Reason::Blocked checks the bounce reason is C<blocked> or not. This
+Sisimai::Reason::Blocked checks the bounce reason is "blocked" or not. This
 class is called only Sisimai::Reason class.
 
 This is the error that SMTP connection was rejected due to a client IP address
-or a hostname, or the parameter of C<HELO/EHLO> command. This reason has added
+or a hostname, or the parameter of "HELO/EHLO" command. This reason has added
 in Sisimai 4.0.0 and does not exist in any version of bounceHammer.
 
     <kijitora@example.net>: 
@@ -131,7 +128,7 @@ in Sisimai 4.0.0 and does not exist in any version of bounceHammer.
 
 =head2 C<B<text()>>
 
-C<text()> returns string: C<blocked>.
+C<text()> returns string: "blocked".
 
     print Sisimai::Reason::Blocked->text;  # blocked
 
@@ -141,9 +138,9 @@ C<match()> returns 1 if the argument matched with patterns defined in this class
 
     print Sisimai::Reason::Blocked->match('Access from ip address 192.0.2.1 blocked');  # 1
 
-=head2 C<B<true( I<Sisimai::Data> )>>
+=head2 C<B<true(I<Sisimai::Data>)>>
 
-C<true()> returns 1 if the bounce reason is C<blocked>. The argument must be
+C<true()> returns 1 if the bounce reason is "blocked". The argument must be
 Sisimai::Data object and this method is called only from Sisimai::Reason class.
 
 =head1 AUTHOR
@@ -152,8 +149,7 @@ azumakuniyuki
 
 =head1 COPYRIGHT
 
-Copyright (C) 2014-2015 azumakuniyuki E<lt>perl.org@azumakuniyuki.orgE<gt>,
-All Rights Reserved.
+Copyright (C) 2014-2015 azumakuniyuki, All rights reserved.
 
 =head1 LICENSE
 
