@@ -6,12 +6,12 @@ use warnings;
 sub text  { 'filtered' }
 sub match {
     # Try to match that the given text and regular expressions
-    # @param    [String] argvs  String to be matched with regular expressions
+    # @param    [String] argv1  String to be matched with regular expressions
     # @return   [Integer]       0: Did not match
     #                           1: Matched
     # @since v4.0.0
     my $class = shift;
-    my $argvs = shift // return undef;
+    my $argv1 = shift // return undef;
     my $regex = qr{(?>
          because[ ]the[ ]recipient[ ]is[ ]only[ ]accepting[ ]mail[ ]from[ ]
             specific[ ]email[ ]addresses    # AOL Phoenix
@@ -32,7 +32,7 @@ sub match {
         )
     }ix;
 
-    return 1 if $argvs =~ $regex;
+    return 1 if $argv1 =~ $regex;
     return 0;
 }
 
@@ -49,17 +49,15 @@ sub true {
     return undef unless ref $argvs eq 'Sisimai::Data';
     return 1 if $argvs->reason eq __PACKAGE__->text;
 
-    require Sisimai::RFC3463;
+    require Sisimai::SMTP::Status;
     require Sisimai::Reason::UserUnknown;
-    my $statuscode = $argvs->deliverystatus // '';
     my $commandtxt = $argvs->smtpcommand // '';
+    my $statuscode = $argvs->deliverystatus // '';
+    my $diagnostic = $argvs->diagnosticcode // '';
+    my $tempreason = Sisimai::SMTP::Status->name( $statuscode );
     my $reasontext = __PACKAGE__->text;
-    my $tempreason = '';
-    my $diagnostic = '';
     my $v = 0;
 
-    $diagnostic = $argvs->diagnosticcode // '';
-    $tempreason = Sisimai::RFC3463->reason( $statuscode );
     return 0 if $tempreason eq 'suspend';
 
     if( $tempreason eq $reasontext ) {
@@ -69,11 +67,9 @@ sub true {
 
             $v = 1 
         }
-
     } else {
         # Check the value of Diagnostic-Code and the last SMTP command
-        my $c = $argvs->smtpcommand;
-        if( $c ne 'RCPT' && $c ne 'MAIL' ) {
+        if( $commandtxt ne 'RCPT' && $commandtxt ne 'MAIL' ) {
             # Check the last SMTP command of the session. 
             if( __PACKAGE__->match( $diagnostic ) ) {
                 # Matched with a pattern in this class
@@ -149,8 +145,7 @@ azumakuniyuki
 
 =head1 COPYRIGHT
 
-Copyright (C) 2014-2015 azumakuniyuki E<lt>perl.org@azumakuniyuki.orgE<gt>,
-All Rights Reserved.
+Copyright (C) 2014-2015 azumakuniyuki, All rights reserved.
 
 =head1 LICENSE
 
