@@ -6,12 +6,12 @@ use warnings;
 sub text  { 'spamdetected' }
 sub match {
     # Try to match that the given text and regular expressions
-    # @param    [String] argvs  String to be matched with regular expressions
+    # @param    [String] argv1  String to be matched with regular expressions
     # @return   [Integer]       0: Did not match
     #                           1: Matched
     # @since v4.1.19
     my $class = shift;
-    my $argvs = shift // return undef;
+    my $argv1 = shift // return undef;
     my $regex = qr{(?>
          ["]The[ ]mail[ ]server[ ]detected[ ]your[ ]message[ ]as[ ]spam[ ]and[ ]
             has[ ]prevented[ ]delivery[.]["]    # CPanel/Exim with SA rejections on
@@ -117,7 +117,7 @@ sub match {
         )
     }xi;
 
-    return 1 if $argvs =~ $regex;
+    return 1 if $argv1 =~ $regex;
     return 0;
 }
 
@@ -138,12 +138,12 @@ sub true {
     return undef unless length $statuscode;
     return 1 if $argvs->reason eq $reasontext;
 
-    require Sisimai::RFC3463;
+    require Sisimai::SMTP::Status;
     my $diagnostic = $argvs->diagnosticcode // '';
     my $v = 0;
 
-    if( Sisimai::RFC3463->reason( $statuscode ) eq $reasontext ) {
-        # Delivery status code points C<rejected>.
+    if( Sisimai::SMTP::Status->name( $statuscode ) eq $reasontext ) {
+        # Delivery status code points "spamdetected".
         $v = 1;
 
     } else {
@@ -161,8 +161,8 @@ __END__
 
 =head1 NAME
 
-Sisimai::Reason::SpamDetected - Bounce reason is C<rejected> due to Spam content in 
-the message or not.
+Sisimai::Reason::SpamDetected - Bounce reason is C<spamdetected> due to Spam 
+content in the message or not.
 
 =head1 SYNOPSIS
 
@@ -171,7 +171,7 @@ the message or not.
 
 =head1 DESCRIPTION
 
-Sisimai::Reason::SpamDetected checks the bounce reason is C<rejected> due to 
+Sisimai::Reason::SpamDetected checks the bounce reason is C<spamdetected> due to 
 Spam content in the message or not. This class is called only Sisimai::Reason 
 class.
 
@@ -210,8 +210,7 @@ azumakuniyuki
 
 =head1 COPYRIGHT
 
-Copyright (C) 2015 azumakuniyuki E<lt>perl.org@azumakuniyuki.orgE<gt>,
-All Rights Reserved.
+Copyright (C) 2015 azumakuniyuki, All rights reserved.
 
 =head1 LICENSE
 
